*=================================================================
*
* Appendix Figure A.1
*
*=================================================================

use "Data\Data_PCE.dta", clear
merge m:m observation_date using "Data\Data_RPCE.dta"
drop _merge
merge m:m observation_date using "Data\Data_Employment.dta"
drop _merge

gen ym = _n - 1 + ym(2002,1)

gen date = dofm(ym)
format date %d

gen year =year(date)
gen month=month(date)

format %tm ym

drop obser
order year month ym date

tsset year month

rename pce* PCE*
rename rpce* RPCE*
foreach var in 	total goods durables durables_motor durables_furnishing durables_recreation ///
				durables_other nondurables nondurables_food nondurables_clothing nondurables_gasoline ///
				nondurables_other services services_hhcons services_housing services_health services_trans ///
				services_recreation services_food services_financial services_other ex_foodenergy foodenergy ///
				hhcons food clothing housing furnishing health transportation communication recreation ///
				education foodservice financial other {
	gen PPCE_`var' = PCE_`var'/RPCE_`var'*100
}


gen RPCE_HtM = RPCE_services_trans + RPCE_services_recreation + RPCE_services_food
gen  PCE_HtM =  PCE_services_trans +  PCE_services_recreation +  PCE_services_food
gen PPCE_HtM = PCE_HtM/RPCE_HtM*100

gen RPCE_exHtM = RPCE_total - RPCE_HtM
gen  PCE_exHtM =  PCE_total -  PCE_HtM
gen PPCE_exHtM = PCE_exHtM/RPCE_exHtM*100

gen emp_HtM  = emp_leisure + emp_retail + emp_transport 
gen emp_exHtM = emp_private - emp_HtM

gen hours_HtM  = hours_leisure + hours_retail + hours_transport 
gen hours_exHtM = hours_private - hours_HtM

foreach var in RPCE_total RPCE_goods RPCE_services RPCE_ex_foodenergy RPCE_HtM RPCE_exHtM ///
			PPCE_total PPCE_goods PPCE_services PPCE_ex_foodenergy PPCE_HtM PPCE_exHtM ///
			emp_total emp_goods emp_services emp_retail emp_leisure emp_transport ///
			emp_HtM emp_exHtM hours_private hours_HtM hours_exHtM {
			
	gen temp = `var'[1+ym(2020,1)-ym(2002,1)]
	gen d_`var' = (`var'/temp-1)*100
	drop temp
}

keep ym month d*

twoway  (line d_emp_total month if ym>=ym(2020,1) & ym<=ym(2020,8), lwidth(thick) lcolor(black)) ///
		(line d_emp_HtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(dash) lcolor(red)) ///
		(scatter d_emp_exHtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(solid) lcolor(blue) msymbol(o) mcolor(blue) mfcolor(white) msize(2.5) connect(direct)), ///
	xline(4.5, lstyle(yxline) lcolor(green)) ///
	text(-1.5 4.5 " --> CARES Act (Apr. 15) ", color(green) place(e) size(2.5) linegap(1.0)) ///
	subtitle("Panel A: Employment", size(3.5)) ///
	legend(order(1 "Total" 2 "Retail, Transportation," "Leisure and Hospitality" 3 "Others") size(2.5) pos(7) ring(0) col(1) rowgap(0.5) region(fcolor(none))) ///
	ylabel(-40(10)0, labsize(2.0)) ///
	xlabel(1(1)8, labsize(2.0)) ///
	ytitle("Percent Deviation from Jan. 2020", size(2.5)) ///
	xtitle("2020", size(2.5)) ///
	saving(fig1, replace)

twoway  (line d_hours_private month if ym>=ym(2020,1) & ym<=ym(2020,8), lwidth(thick) lcolor(black)) ///
		(line d_hours_HtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(dash) lcolor(red)) ///
		(scatter d_emp_exHtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(solid) lcolor(blue) msymbol(o) mcolor(blue) mfcolor(white) msize(2.5) connect(direct)), ///
		xline(4.5, lstyle(yxline) lcolor(green)) ///
	subtitle("Panel B: Total Hours", size(3.5)) ///
	legend(order(1 "Total" 2 "Retail, Transportation," "Leisure and Hospitality" 3 "Others") size(2.5) pos(7) ring(0) col(1) rowgap(0.5) region(fcolor(none))) ///
	ylabel(-40(10)0, labsize(2.0)) ///
	xlabel(1(1)8, labsize(2.0)) ///
	ytitle("Percent Deviation from Jan. 2020", size(2.5)) ///
	xtitle("2020", size(2.5)) ///
	saving(fig2, replace)


twoway  (line d_RPCE_total month if ym>=ym(2020,1) & ym<=ym(2020,8), lwidth(thick) lcolor(black)) ///
		(line d_RPCE_HtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(dash) lcolor(red)) ///
		(scatter d_RPCE_exHtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(solid) lcolor(blue) msymbol(o) mcolor(blue) mfcolor(white) msize(2.5) connect(direct)), ///
		xline(4.5, lstyle(yxline) lcolor(green)) ///
	subtitle("Panel C: Real PCE", size(3.5)) ///
	legend(order(1 "Total" 2 "Transportation, Recreation," "and Food Services" 3 "Others") size(2.5) pos(7) ring(0) col(1) rowgap(0.5) region(fcolor(none))) ///
	ylabel(-70(10)10, labsize(2.0)) ///
	xlabel(1(1)8, labsize(2.0)) ///
	ytitle("Percent Deviation from Jan. 2020", size(2.5)) ///
	xtitle("2020", size(2.5)) ///
	saving(fig3, replace)


twoway  (line d_PPCE_total month if ym>=ym(2020,1) & ym<=ym(2020,8), lwidth(thick) lcolor(black)) ///
		(line d_PPCE_HtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(dash) lcolor(red)) ///
		(scatter d_PPCE_exHtM month if ym>=ym(2020,1) & ym<=ym(2020,8), lpattern(solid) lcolor(blue) msymbol(o) mcolor(blue) mfcolor(white) msize(2.5) connect(direct)), ///
		xline(4.5, lstyle(yxline) lcolor(green)) ///
	subtitle("Panel D: PCE Inflation", size(3.5)) ///
	legend(order(1 "Total" 2 "Transportation, Recreation," "and Food Services" 3 "Others") size(2.5) pos(7) ring(0) col(1) rowgap(0.5) region(fcolor(none))) ///
	ylabel(-2(0.5)1, labsize(2.0)) ///
	xlabel(1(1)8, labsize(2.0)) ///
	ytitle("Percent Deviation from Jan. 2020", size(2.5)) ///
	xtitle("2020", size(2.5)) ///
	saving(fig4, replace)


gr combine fig1.gph fig2.gph fig3.gph fig4.gph, xsize(6.5) ysize(6) plotregion(margin(0 0 -3 0)) cols(2) imargin(zero)

graph export "../Output_Figure/Appendix_Figure_A1.eps", as(eps) preview(off) replace 
graph export "../Output_Figure/Appendix_Figure_A1.png", replace 

foreach i of numlist 1/4 {
rm fig`i'.gph
}



*=================================================================
*
* Appendix Table C.1 "Data"
*
*=================================================================

clear
set more off

* GDP (Quarterly)
use "Data\Data_RGDP.dta", clear
keep date RGDP_Total
generate qm = tq(2005q1) + _n-1 
gen date2 = dofq(qm)
format date2 %d

gen year =year(date2)
gen quarter=quarter(date2)
format %tq date
drop date2 qm

tsset year quarter
foreach var in RGDP_Total {
	gen temp = `var'[1+yq(2020,1)-yq(2005,1)]
	gen d2020_`var' = (`var'/temp-1)*100
}
drop temp RGDP date
keep if year == 2020 & quarter < 4
order year quarter 
save tmp.dta, replace

use "Data\Data_PCE.dta", clear
merge m:m observation_date using "Data\Data_RPCE.dta"
drop _merge
merge m:m observation_date using "Data\Data_Employment.dta"
drop _merge

gen ym = _n - 1 + ym(2002,1)

gen date = dofm(ym)
format date %d

gen year =year(date)
gen month=month(date)

format %tm ym

drop obser
order year month ym date

tsset year month

rename pce* PCE*
rename rpce* RPCE*
foreach var in 	total goods durables durables_motor durables_furnishing durables_recreation ///
				durables_other nondurables nondurables_food nondurables_clothing nondurables_gasoline ///
				nondurables_other services services_hhcons services_housing services_health services_trans ///
				services_recreation services_food services_financial services_other ex_foodenergy foodenergy ///
				hhcons food clothing housing furnishing health transportation communication recreation ///
				education foodservice financial other {
	gen PPCE_`var' = PCE_`var'/RPCE_`var'*100
}

gen RPCE_HtM = RPCE_services_trans + RPCE_services_recreation + RPCE_services_food
gen  PCE_HtM =  PCE_services_trans +  PCE_services_recreation +  PCE_services_food
gen PPCE_HtM = PCE_HtM/RPCE_HtM*100

gen RPCE_exHtM = RPCE_total - RPCE_HtM
gen  PCE_exHtM =  PCE_total -  PCE_HtM
gen PPCE_exHtM = PCE_exHtM/RPCE_exHtM*100

gen emp_HtM  = emp_leisure + emp_retail + emp_transport 
gen emp_exHtM = emp_private - emp_HtM

gen hours_HtM  = hours_leisure + hours_retail + hours_transport 
gen hours_exHtM = hours_private - hours_HtM


keep year month ym date RPCE_total RPCE_goods RPCE_services RPCE_ex_foodenergy RPCE_HtM RPCE_exHtM ///
			PPCE_total PPCE_goods PPCE_services PPCE_ex_foodenergy PPCE_HtM PPCE_exHtM ///
			emp_total emp_private emp_goods emp_services emp_retail emp_leisure emp_transport ///
			emp_HtM emp_exHtM hours_HtM hours_exHtM hours_private

			
foreach var in RPCE_total RPCE_goods RPCE_services RPCE_ex_foodenergy RPCE_HtM RPCE_exHtM ///
			PPCE_total PPCE_goods PPCE_services PPCE_ex_foodenergy PPCE_HtM PPCE_exHtM ///
			emp_total emp_goods emp_services emp_retail emp_leisure emp_transport ///
			emp_HtM emp_exHtM hours_HtM hours_exHtM {
			
	gen t_`var' = (`var' + l.`var')/2
}

keep if month/2 == floor(month/2)
gen t = _n
tsset t
foreach var in RPCE_total RPCE_goods RPCE_services RPCE_ex_foodenergy RPCE_HtM RPCE_exHtM ///
			PPCE_total PPCE_goods PPCE_services PPCE_ex_foodenergy PPCE_HtM PPCE_exHtM ///
			emp_total emp_goods emp_services emp_retail emp_leisure emp_transport ///
			emp_HtM emp_exHtM hours_HtM hours_exHtM {
			
	drop `var'
	rename t_`var' `var'
	
	gen D_`var' = (`var'/l.`var'-1)*100

	gen temp = `var'[1+(ym(2020,1) - ym(2002,1))/2]
	gen d2020_`var' = (`var'/temp-1)*100
	drop temp
}

keep year month d2020_hours_HtM d2020_hours_exHtM d2020_PPCE_HtM d2020_PPCE_exHtM ///
	  d2020_RPCE_HtM d2020_RPCE_exHtM d2020_RPCE_total
keep if year == 2020 & month <= 8
order year month d2020_hours_HtM d2020_hours_exHtM d2020_PPCE_HtM d2020_PPCE_exHtM ///
	  d2020_RPCE_HtM d2020_RPCE_exHtM d2020_RPCE_total
gen quarter = _n
replace quarter = . if quarter > 3

merge m:m year quarter using tmp.dta
drop if month == 2
drop _merge
rm tmp.dta

format %4.2f d2020_hours_HtM d2020_hours_exHtM d2020_PPCE_HtM d2020_PPCE_exHtM ///
			 d2020_RPCE_HtM d2020_RPCE_exHtM d2020_RPCE_total d2020_RGDP_Total
outsheet year month d2020_hours_HtM d2020_hours_exHtM d2020_PPCE_HtM ///
		 d2020_PPCE_exHtM d2020_RPCE_HtM d2020_RPCE_exHtM d2020_RPCE_total quarter ///
		 d2020_RGDP_Total using ../Output_Table/Online_Appendix_Table_C1_Data.csv, comma replace
