% Initialization
beta    = (0.98)^(1/6) ;   % Time discount
sigma   = 1.0  	;   % Inverse of EIS (CEE 2005)
varphi  = 0.3   ;   % Inverse of Frisch (CEE 2005)

alpha_R = 0.72 	;   % weight on R-good: Ricardian HH (CEX data)
alpha_H = 0.28  ;   % weight on R-good: HTM HH (CEX data)0
lambda  = 0.234 ;   % population (fraction) of HtM HH
thetaR  = 4     ;   % ES across varieties
thetaH  = 4     ;   % ES across varieties
epsilon = 2.0   ;   % ES between R and H-goods
gamma   = 0     ;   % Price indexation
rho_xi  = 0.0   ;   % Persistence of preference shock
alpha   = 1.0   ;   % Labor share

omegaR  = 0.75  ;   % Calvo parameter for R-sector
omegaH  = 0.80  ;   % Calvo parameter for HtM-sector

% Fiscal variables
tf_Y    = 12.7/100  ;   % total transfer to GDP ratio
TL_Y    = 12.2/100  ;   % labor tax revenue to GDP ratio
b_Y     = 50.9/100  ;   % Debt to GDP ratio
b_Y     = 6*b_Y     ;

xi      = 1.0       ;   % Fraction of transfers going to HTM HH
zeta    = 0.0       ;   % Progessivity of Labor Tax (=0 : no labor tax for HTM)

% Inflation steady-state
pi_Rss  = 1     ;
pi_Hss  = 1     ;
pi_ss   = lambda*pi_Hss + (1-lambda)*pi_Rss     ;
Rss     = 1/beta*pi_Rss ;

% Taylor rule
rhoR1   = 1.12  ;
rhoR2   = -0.18 ;

% Tax smoothing
rho_LR  = 0.84 ;

save Dynare//para_file beta sigma varphi gamma alpha_R alpha_H lambda ...
     epsilon thetaR thetaH alpha zeta omegaR omegaH tf_Y xi TL_Y b_Y ...
     pi_Rss pi_Hss pi_ss Rss rho_xi rhoR1 rhoR2 rho_LR  ;

% Figures
Long_Horizon  = 3000;
Short_Horizon = 12  ;

var_fig_names = ...
    {{'\makebox[4in][c]{$C^R_t$}'}, ...
    {'\makebox[4in][c]{$C^H_t$}'}, ...
    {'\makebox[4in][c]{$C^R_{R,t}$}'}, ...
    {'\makebox[4in][c]{$C^R_{H,t}$}'}, ...
    {'\makebox[4in][c]{$C^H_{R,t}$}'}, ...
    {'\makebox[4in][c]{$C^H_{H,t}$}'}, ...
    {'\makebox[4in][c]{$C_{t} (Y_{t})$}'}, ...
    {'\makebox[4in][c]{$Y_{R,t}$}'}, ...
    {'\makebox[4in][c]{$Y_{H,t}$}'}, ...
    {'\makebox[4in][c]{$Q_{t}$}'}, ...
    {'\makebox[4in][c]{$S_{R,t}$}'},...
    {'\makebox[4in][c]{$S_{H,t}$}'},...
    {'\makebox[4in][c]{$i_{t}$}'},...
    {'\makebox[4in][c]{$\pi_{t}$}'},...
    {'\makebox[4in][c]{$\pi^R_{t}$}'},...
    {'\makebox[4in][c]{$\pi^H_{t}$}'},...
    {'\makebox[4in][c]{$\pi_{R,t}$}'},...
    {'\makebox[4in][c]{$\pi_{H,t}$}'},...
    {'\makebox[4in][c]{$L_{R,t}$}'},...
    {'\makebox[4in][c]{$L_{H,t}$}'},...
    {'\makebox[4in][c]{$w^R_{t}$}'},...
    {'\makebox[4in][c]{$w^H_{t}$}'},...
    {'\makebox[4in][c]{$b_{t}$}'},...
    {'\makebox[4in][c]{$\tau_{t}$}'},...
    {'\makebox[4in][c]{$T^L_{t}$}'},...
    {'\makebox[4in][c]{$\tau^R_{L,t}$}'},...
    {'\makebox[4in][c]{$\tau^H_{L,t}$}'},...
    {'\makebox[4in][c]{$s_{t}$}'},...
    {'\makebox[4in][c]{$s^R_{t}$}'},...
    {'\makebox[4in][c]{$s^H_{t}$}'},...
    {'\makebox[4in][c]{Profit(R)}'},...
    {'\makebox[4in][c]{Profit(H)}'}} ;

lightred    = [255 227 227]/255 ;
lightblue   = [228 246 248]/255 ;
midblue1    = [100 150 248]/255 ;
midblue2    = [120 120 255]/255 ;
darkblue    = [30 30 130]/255   ;
lightgray   = [0.9 0.9 0.9]     ;
oldgreen    = [0.4660 0.6740 0.1880];
midred      = [255 120 120]/255     ;
darkred     = [130 10 10]/255       ;
amaranth    = [0.9, 0.17, 0.31]     ;
cardinal    = [0.77, 0.12, 0.23]    ;

tab_blue    = [31 119 180]/255      ;
tab_orange  = [255 127 14]/255      ;
tab_green   = [44 160 44]/255       ;
tab_red     = [214 39 40]/255       ;
tab_purple  = [148 103 189]/255     ;
tab_light_blue  = [174 199 232]/255 ;
tab_light_orange= [255 187 120]/255 ;
tab_light_green = [152 223 138]/255 ;
tab_light_red   = [255 152 150]/255 ;
tab_light_purple= [197 176 213]/255 ;

lp = {'-','-.',':','--','-'}    ;
