clear; clc; close all;

lightred    = [255 227 227]/255 ;
lightblue   = [228 246 248]/255 ;
midblue1    = [100 150 248]/255 ;
midblue2    = [120 120 255]/255 ;
darkblue    = [30 30 130]/255   ;
lightgray   = [0.9 0.9 0.9]     ;
oldgreen    = [0.4660 0.6740 0.1880];
midred      = [255 120 120]/255     ;
darkred     = [130 10 10]/255       ;
amaranth    = [0.9, 0.17, 0.31]     ;
cardinal    = [0.77, 0.12, 0.23]    ;

tab_blue    = [31 119 180]/255      ;
tab_orange  = [255 127 14]/255      ;
tab_green   = [44 160 44]/255       ;
tab_red     = [214 39 40]/255       ;
tab_purple  = [148 103 189]/255     ;
tab_light_blue  = [174 199 232]/255 ;
tab_light_orange= [255 187 120]/255 ;
tab_light_green = [152 223 138]/255 ;
tab_light_red   = [255 152 150]/255 ;
tab_light_purple= [197 176 213]/255 ;

lp = {'-','-.',':','--','-'}    ;

var_fig_names = ...
    {{'\makebox[4in][c]{$C^R_t$}'}, ...
    {'\makebox[4in][c]{$C^H_t$}'}, ...
    {'\makebox[4in][c]{$s_{t}$}'},...
    {'\makebox[4in][c]{$Y_{t}$}'}, ...
    {'\makebox[4in][c]{$L^R_{t}$}'}, ...
    {'\makebox[4in][c]{$\Pi_{t}$}'}, ...
    {'\makebox[4in][c]{$i_{t}$}'}, ...
    {'\makebox[4in][c]{$(1+i_{t})/\Pi_{t+1}$}'}, ...
    {'\makebox[4in][c]{$b_{t}$}'}, ...
    {'\makebox[4in][c]{$\tau_{t}$}'}} ;

%% Parameters
beta    = 0.99          ;   % Time discount
lambda  = 0.234         ;   % Population (fraction) of Ricardian HH
s_Y     = 12.7/100      ;   % Total transfer to GDP ratio
b_Y     = 6*50.9/100    ;   % Debt to (Annual) GDP ratio
pi_ss   = 1             ;   % Steady-state inflation rate
Rss     = 1/beta*pi_ss  ;   % Steady-state nominal rate
rho_b   = 0.0           ;   % Persistence of preference shocks

%   Positions of Variables !!!
Betapos =   1;
Pipos   =   2;
Rpos    =   3;
RRpos   =   4;
Spos    =   5; 
Bpos    =   6;
Taupos  =   7;
CRpos   =   8;

Numsim  = 100    ;

varphi_seq = [0 2.0];
s_shock_period_seq = [1 1 1];
b_shock_period_seq = [1 3 5];


%% Itereate with different degrees of Frisch elasticity

for i_varphi = 1:length(varphi_seq)

    % Calculate model steady-state
    varphi  = varphi_seq(i_varphi)  ;   % Inverse of Frisch
    LRss    = 0.3                   ;
    Yss     = (1-lambda)*LRss       ;
    CRss    = (1-s_Y)/(1-lambda)*Yss;
    wss     = 1                     ;
    chi     = wss/(LRss^varphi*CRss);
    bss     = b_Y*Yss               ;
    sss     = s_Y*Yss               ;
    CHss    = 1/lambda*sss          ;
    Lss     = LRss*(1-lambda)       ;
    tauss   = sss - (1-1/beta)*bss  ;

    x_steady= [0 pi_ss Rss Rss/pi_ss sss bss tauss CRss] ;
    x_ss    = kron(ones(Numsim,1),x_steady) ;
    xnum    = length(x_steady)      ;   % # of variables in system 

    temp_x  = x_ss'    ;
    x       = temp_x(:)   ;

    save para_file_csolve x_steady beta chi lambda varphi rho_b ...
                          Betapos RRpos Spos Bpos Taupos Rpos Pipos CRpos ...
                          CRss Rss tauss pi_ss bss sss xnum Numsim

    for ii = 1:length(s_shock_period_seq)
        s_shock_period = s_shock_period_seq(ii) ;
        b_shock_period = b_shock_period_seq(ii) ;

        save para_file_csolve s_shock_period b_shock_period -append

        %% Baseline: Monetary Regime
        phi     = 1.5   ;   % Taylor rule
        psi     = 0.1   ;   % Tax rule
        std_s   = 0.01  ;   % Size of transfer
        std_b   = 0.00  ;   % Size of preference shock
        save para_file_csolve phi psi std_s std_b -append

        x_sol = csolve2('Model_System_T',x,[],10e-9,1000);

        x_path = reshape(x_sol,xnum,Numsim)'    ;
        x_path = [x_steady ; x_path]            ;

        beta_s  = x_path(:,Betapos) ; pi = x_path(:,Pipos)  ; R = x_path(:,Rpos) ;
        realR   = x_path(:,RRpos)   ; s  = x_path(:,Spos)   ; b = x_path(:,Bpos) ;
        tau     = x_path(:,Taupos)  ; cR = x_path(:,CRpos);
        cH      = 1/lambda*s  ; y  = (1-lambda)*cR + s ; lR = cR + 1/(1-lambda)*s ;

        var = [cR cH s y lR pi R realR b tau] ;
        var_ss = var(1,:) ;
        for k = 1:10
            if k >= 6 && k <= 8
                var(:,k) = (var(:,k)-1)*100 ;
            elseif var_ss(k) ~= 0  
                var(:,k) = (var(:,k)./var_ss(k)-1)*100 ;
            end
        end
        var = round(var(2:end,:),8) ;
        sum_pi(ii) = sum(log(pi/pi(1)))*100;

        %% Baseline: Fiscal Regime
        phi     = 0.0   ;   % Taylor rule
        psi     = 0.00001;  % Tax rule  
        std_s   = 0.01  ;   % Size of transfer
        std_b   = 0.00  ;   % Size of preference shock
        save para_file_csolve phi psi std_s std_b -append

        x_sol = csolve2('Model_System_T',x,[],10e-9,1000);

        x_path = reshape(x_sol,xnum,Numsim)'    ;
        x_path = [x_steady ; x_path]            ;

        beta_s  = x_path(:,Betapos) ; pi = x_path(:,Pipos)  ; R = x_path(:,Rpos) ;
        realR   = x_path(:,RRpos)   ; s  = x_path(:,Spos)   ; b = x_path(:,Bpos) ;
        tau     = x_path(:,Taupos)  ; cR = x_path(:,CRpos);
        cH      = 1/lambda*s  ; y  = (1-lambda)*cR + s ; lR = cR + 1/(1-lambda)*s ;

        var_PMAF = [cR cH s y lR pi R realR b tau] ;
        for k = 1:10
            if k >= 6 && k <= 8
                var_PMAF(:,k) = (var_PMAF(:,k)-1)*100 ;
            elseif var_ss(k) ~= 0  
                var_PMAF(:,k) = (var_PMAF(:,k)./var_ss(k)-1)*100 ;
            end
        end
        var_PMAF = round(var_PMAF(2:end,:),8) ;
        sum_pi_PMAF(ii) = sum(log(pi/pi(1)))*100;

        %% Preference shocks: Monetary Regime
        phi     = 1.5   ;   % Taylor rule
        psi     = 0.1   ;   % Tax rule  
        std_s   = 0.01  ;   % Size of transfer
        std_b   = -0.02 ;   % Size of preference shock
        save para_file_csolve phi psi std_s std_b -append

        x_sol = csolve2('Model_System_T',x,[],10e-9,1000);

        x_path = reshape(x_sol,xnum,Numsim)'    ;
        x_path = [x_steady ; x_path]            ;

        beta_s  = x_path(:,Betapos) ; pi = x_path(:,Pipos)  ; R = x_path(:,Rpos) ;
        realR   = x_path(:,RRpos)   ; s  = x_path(:,Spos)   ; b = x_path(:,Bpos) ;
        tau     = x_path(:,Taupos)  ; cR = x_path(:,CRpos);
        cH      = 1/lambda*s  ; y  = (1-lambda)*cR + s ; lR = cR + 1/(1-lambda)*s ;

        var_pref = [cR cH s y lR pi R realR b tau] ;
        for k = 1:10
            if k >= 6 && k <= 8
                var_pref(:,k) = (var_pref(:,k)-1)*100 ;
            elseif var_ss(k) ~= 0  
                var_pref(:,k) = (var_pref(:,k)./var_ss(k)-1)*100 ;
            end
        end
        var_pref = round(var_pref(2:end,:),8) ;
        sum_pi_pref(ii) = sum(log(pi/pi(1)))*100;

        %% Preference shocks: Fiscal Regime
        phi     = 0.0   ;   % Taylor rule
        psi     = 0.00001;  % Tax rule
        std_s   = 0.01  ;   % Size of transfer
        std_b   = -0.02 ;   % Size of preference shock
        save para_file_csolve phi psi std_s std_b -append

        x_sol = csolve2('Model_System_T',x,[],10e-9,1000);

        x_path = reshape(x_sol,xnum,Numsim)'    ;
        x_path = [x_steady ; x_path]            ;

        beta_s  = x_path(:,Betapos) ; pi = x_path(:,Pipos)  ; R = x_path(:,Rpos) ;
        realR   = x_path(:,RRpos)   ; s  = x_path(:,Spos)   ; b = x_path(:,Bpos) ;
        tau     = x_path(:,Taupos)  ; cR = x_path(:,CRpos);
        cH      = 1/lambda*s  ; y  = (1-lambda)*cR + s ; lR = cR + 1/(1-lambda)*s ;

        var_pref_PMAF = [cR cH s y lR pi R realR b tau] ;
        for k = 1:10
            if k >= 6 && k <= 8
                var_pref_PMAF(:,k) = (var_pref_PMAF(:,k)-1)*100 ;
            elseif var_ss(k) ~= 0  
                var_pref_PMAF(:,k) = (var_pref_PMAF(:,k)./var_ss(k)-1)*100 ;
            end
        end
        var_pref_PMAF = round(var_pref_PMAF(2:end,:),8) ;
        sum_pi_pref_PMAF(ii) = sum(log(pi/pi(1)))*100;


    %% Save Online_Appendix Figures B.1 and B.3
        if ii == 1
        Short_Horizon = 4 ;
        fig1 = figure;
        for i = 1:10
            subplot(3,5,i)
            plot(0:Short_Horizon,var(1:Short_Horizon+1,i),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
            plot(0:Short_Horizon,var_PMAF(1:Short_Horizon+1,i),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
            plot(0:Short_Horizon,var_pref(1:Short_Horizon+1,i),lp{3},'Color',tab_green,'linewidth',1.5) ; hold on
            plot(0:Short_Horizon,var_pref_PMAF(1:Short_Horizon+1,i),lp{4},'Color',tab_orange,'linewidth',1.5) ; hold on
            set(gca,'Xcolor',[0 0 0],'XTick',0:1:Short_Horizon,'FontSize',6,'FontName','Times New Roman',...
                'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
            hh = gca ;
            hh.YBaseline.Visible = 'off'  ;
        %     axis tight ;
            title(var_fig_names{i},'Interpreter','Latex','FontSize',8) ;
            if i == 1 || i == 6
            ylabel('percent','Interpreter','Latex','FontSize',8) ;
            end
            if i >= 6
            xlabel('Time','Interpreter','Latex','FontSize',8) ;
            end
        end
        hSub = subplot(3,5,11:15) ;
        plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2); 
        plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2); hold on ; plot(1,NaN,lp{4},'Color',tab_orange,'LineWidth',2);
        set(hSub, 'Visible', 'off');
        h = legend(hSub,'M-Regime','F-Regime','M-Regime with Preference Shocks','F-Regime with Preference Shocks'...
                       ,'Orientation','Horizontal','NumColumns',2);
        h.FontSize = 8 ;
        h.Interpreter = 'latex';
        h.Location = 'northoutside' ;

        set(fig1,'Units','Inches');
        pos = get(fig1,'Position');
        set(fig1,'PaperPositionMode','auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
        if varphi == 0
        print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B1.png'))  ;
        print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B1.eps'))  ;
        else
        print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B3.png'))  ;
        print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B3.eps'))  ;
        end
        end
    end

    %% Online_Appendix Table B.1: Sum of inflation response
    T_1 = round([sum_pi(1) ; sum_pi_PMAF(1); sum_pi_pref(1); sum_pi_pref_PMAF(1)],2) ;
    T_3 = round([sum_pi(2) ; sum_pi_PMAF(2); sum_pi_pref(2); sum_pi_pref_PMAF(2)],2) ;
    T_5 = round([sum_pi(3) ; sum_pi_PMAF(3); sum_pi_pref(3); sum_pi_pref_PMAF(3)],2) ;

    if varphi == 0
        Panel_A = {'M-Regime','F-Regime','M-Regime with Beta Shock','F-Regime with Beta Shock'}' ;
        Table_B1_Panel_A = table(Panel_A,T_1,T_3,T_5) ;
    else
        Panel_B = {'M-Regime','F-Regime','M-Regime with Beta Shock','F-Regime with Beta Shock'}' ;
        Table_B1_Panel_B = table(Panel_B,T_1,T_3,T_5) ;
    end

    
    %% Loop for diferent size of preference shocks
    std_b_seq = unique([-0.04:0.01:0]) ;
    s_shock_period = 1 ;
    b_shock_period = 1 ;
    save para_file_csolve s_shock_period b_shock_period -append

    for i = 1:length(std_b_seq)
        std_s   = 0.01          ;	% Size of transfer
        std_b   = std_b_seq(i)  ;   % Size of preference shock
        save para_file_csolve std_s std_b -append

        % Monetary regime
        phi     = 1.5   ;   % Taylor rule
        psi     = 0.1   ;   % Tax rule
        save para_file_csolve phi psi -append

        x_sol = csolve2('Model_System_T',x,[],10e-9,1000);

        x_path = reshape(x_sol,xnum,Numsim)'    ;
        x_path = [x_steady ; x_path]            ;

        beta_s  = x_path(:,Betapos) ; pi = x_path(:,Pipos)  ; R = x_path(:,Rpos) ;
        realR   = x_path(:,RRpos)   ; s  = x_path(:,Spos)   ; b = x_path(:,Bpos) ;
        tau     = x_path(:,Taupos)  ; cR = x_path(:,CRpos);
        cH      = 1/lambda*s  ; y  = (1-lambda)*cR + s ; lR = cR + 1/(1-lambda)*s ;

        var_pref_tmp = [cR cH s y lR pi R realR b tau] ;
        var_pref_level(:,:,i) = var_pref_tmp(2:end,:);
        for k = 1:10
            if k >= 6 && k <= 8
                var_pref_tmp(:,k) = (var_pref_tmp(:,k)-1)*100 ;
            elseif var_ss(k) ~= 0  
                var_pref_tmp(:,k) = (var_pref_tmp(:,k)./var_ss(k)-1)*100 ;
            end
        end
        var_pref_seq(:,:,i) = round(var_pref_tmp(2:end,:),8) ;
        sum_pi_pref_seq(i,1) = sum(log(pi/pi(1)))*100;

        % Fiscal regime
        phi     = 0.0   ;   % Taylor rule
        psi     = 0.00001;  % Tax rule 
        save para_file_csolve phi psi -append

        x_sol = csolve2('Model_System_T',x,[],10e-9,1000);

        x_path = reshape(x_sol,xnum,Numsim)'    ;
        x_path = [x_steady ; x_path]            ;

        beta_s  = x_path(:,Betapos) ; pi = x_path(:,Pipos)  ; R = x_path(:,Rpos) ;
        realR   = x_path(:,RRpos)   ; s  = x_path(:,Spos)   ; b = x_path(:,Bpos) ;
        tau     = x_path(:,Taupos)  ; cR = x_path(:,CRpos);
        cH      = 1/lambda*s  ; y  = (1-lambda)*cR + s ; lR = cR + 1/(1-lambda)*s ;

        var_pref_PMAF_tmp = [cR cH s y lR pi R realR b tau] ;
        var_pref_PMAF_level(:,:,i) = var_pref_PMAF_tmp(2:end,:);
        for k = 1:10
            if k >= 6 && k <= 8
                var_pref_PMAF_tmp(:,k) = (var_pref_PMAF_tmp(:,k)-1)*100 ;
            elseif var_ss(k) ~= 0  
                var_pref_PMAF_tmp(:,k) = (var_pref_PMAF_tmp(:,k)./var_ss(k)-1)*100 ;
            end
        end
        var_pref_PMAF_seq(:,:,i) = round(var_pref_PMAF_tmp(2:end,:),8) ;
        sum_pi_pref_PMAF_seq(i,1) = sum(log(pi/pi(1)))*100;
    end


    %% Save Online_Appendix Figures B.2 and B.4
    ii = sum(var_pref_PMAF_seq(1,6,:)<var_pref_seq(1,6,:)) ;
    step = (std_b_seq(end)-std_b_seq(1))/4;
    xxtick = [round([std_b_seq(1):step:std_b_seq(end)]*100,2)];

    Short_Horizon = 4 ;
    fig1 = figure;
    subplot(2,3,1)
    plot(std_b_seq*100,squeeze(var_pref_seq(1,6,:)),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
    plot(std_b_seq*100,squeeze(var_pref_PMAF_seq(1,6,:)),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
    set(gca,'Xcolor',[0 0 0],'XTick',sort(xxtick),'FontSize',6,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'on'  ;
    title('Inflation at $t=0$: $\Pi_{0}$','Interpreter','Latex','FontSize',8) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;
    xlabel('Size of Preference Shocks (\%)','Interpreter','Latex','FontSize',7.5) ;

    subplot(2,3,2)
    plot(std_b_seq*100,squeeze(var_pref_seq(2,6,:)),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
    plot(std_b_seq*100,squeeze(var_pref_PMAF_seq(2,6,:)),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
    set(gca,'Xcolor',[0 0 0],'XTick',sort(xxtick),'FontSize',6,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'on'  ;
    title('Inflation at $t=1$: $\Pi_{1}$','Interpreter','Latex','FontSize',8) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;
    xlabel('Size of Preference Shocks (\%)','Interpreter','Latex','FontSize',7.5) ;

    subplot(2,3,3)
    plot(std_b_seq*100,sum_pi_pref_seq,lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
    plot(std_b_seq*100,sum_pi_pref_PMAF_seq,lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
    set(gca,'Xcolor',[0 0 0],'XTick',sort(xxtick),'FontSize',6,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'on'  ;
    title('Sum of Inflation: $\sum_{t=0}^\infty \log(\Pi_t/\bar{\Pi})$','Interpreter','Latex','FontSize',8) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;
    xlabel('Size of Preference Shocks (\%)','Interpreter','Latex','FontSize',7.5) ;

    subplot(2,3,4)
    plot(std_b_seq*100,squeeze(var_pref_seq(1,9,:)),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
    plot(std_b_seq*100,squeeze(var_pref_PMAF_seq(1,9,:)),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
    set(gca,'Xcolor',[0 0 0],'XTick',sort(xxtick),'FontSize',6,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'on'  ;
    title('Debt at $t=0$: $b_{0}$','Interpreter','Latex','FontSize',8) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;
    xlabel('Size of Preference Shocks (\%)','Interpreter','Latex','FontSize',7.5) ;

    subplot(2,3,5)
    plot(std_b_seq*100,100*(squeeze(var_pref_level(1,7,:))-1),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
    plot(std_b_seq*100,100*(squeeze(var_pref_PMAF_level(1,7,:))-1),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
    set(gca,'Xcolor',[0 0 0],'XTick',sort(xxtick),'FontSize',6,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'on'  ;
    title('(Net) Nominal Rate: $i_{0}$','Interpreter','Latex','FontSize',8) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;
    xlabel('Size of Preference Shocks (\%)','Interpreter','Latex','FontSize',7.5) ;

    subplot(2,3,6)
    plot(std_b_seq*100,100*(round(squeeze(var_pref_level(1,8,:))-1,7)),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
    plot(std_b_seq*100,100*(round(squeeze(var_pref_PMAF_level(1,8,:))-1,7)),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
    set(gca,'Xcolor',[0 0 0],'XTick',sort(xxtick),'FontSize',6,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'on'  ;
    title('(Net) Real Rate: $(1+i_0)/\Pi_1-1$','Interpreter','Latex','FontSize',8) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;
    xlabel('Size of Preference Shocks (\%)','Interpreter','Latex','FontSize',7.5) ;

    h = legend('M-Regime','F-Regime','Orientation','Horizontal','NumColumns',1);
    h.FontSize = 8 ;
    h.Interpreter = 'latex';
    h.Location = 'northwest' ;

    set(fig1,'Units','Inches');
    pos = get(fig1,'Position');
    set(fig1,'PaperPositionMode','auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
    if varphi == 0
    print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B2.png'))  ;
    print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B2.eps'))  ;
    else
    print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B4.png'))  ;
    print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_B4.eps'))  ;
    end
    
    delete para_file_csolve.mat
end

%% Print Online_Appendix Table B.1
clc;
disp('    ================================================================')
disp('    ***      Online_Appendix Table B.1. Sum of Inflation Responses      ***')
disp('    ================================================================')
disp(' ')

disp('    * Panel A: Infinite Frisch Elasticity (varphi = 0)')
disp(Table_B1_Panel_A);
disp(' ')
disp('    * Panel B: Finite Frisch Elasticity (varphi = 2)')
disp(Table_B1_Panel_B);
disp(' ')
writetable(Table_B1_Panel_A,'..\Output_Table\Online_Appendix_Table_B1.csv','WriteRowNames',true);
writetable(Table_B1_Panel_B,'..\Output_Table\Online_Appendix_Table_B1.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
