clear; clc; close all;

lightred    = [255 227 227]/255 ;
lightblue   = [228 246 248]/255 ;
midblue1    = [100 150 248]/255 ;
midblue2    = [120 120 255]/255 ;
darkblue    = [30 30 130]/255   ;
lightgray   = [0.9 0.9 0.9]     ;
oldgreen    = [0.4660 0.6740 0.1880];
midred      = [255 120 120]/255     ;
darkred     = [130 10 10]/255       ;
amaranth    = [0.9, 0.17, 0.31]     ;
cardinal    = [0.77, 0.12, 0.23]    ;

tab_blue    = [31 119 180]/255      ;
tab_orange  = [255 127 14]/255      ;
tab_green   = [44 160 44]/255       ;
tab_red     = [214 39 40]/255       ;
tab_purple  = [148 103 189]/255     ;
tab_light_blue  = [174 199 232]/255 ;
tab_light_orange= [255 187 120]/255 ;
tab_light_green = [152 223 138]/255 ;
tab_light_red   = [255 152 150]/255 ;
tab_light_purple= [197 176 213]/255 ;

lp = {'-','-.',':','--','-'}    ;

var_fig_names = ...
    {{'\makebox[4in][c]{$\Pi_{t}$}'}, ...
    {'\makebox[4in][c]{$Y_{t}$}'}, ...
    {'\makebox[4in][c]{$s_{t}$}'},...
    {'\makebox[4in][c]{$G_{t}$}'}, ...
    {'\makebox[4in][c]{$\tau_{t}$}'}} ;

s_shock_values      = [0.01 0 0] ;
beta_shock_values   = [0    0 0] ;
g_shock_values      = [0    0 0] ;
save Dynare//shock_file s_shock_values beta_shock_values g_shock_values;

varphi_seq = [0 2] ;

for ii = 1:length(varphi_seq)
    
    % Initialization
    beta    = 0.99  ;       % Time discount
    varphi  = varphi_seq(ii);% Inverse of Frisch
    lambda  = 0.234 ;       % population (fraction) of Ricardian HH

    % Monetary/Fiscal variables
    s_Y     = 12.7/100      ;   % Total transfer to GDP ratio
    b_Y     = 6*50.9/100    ;   % Debt to (Annual) GDP ratio
    g_Y     = 15.0/100  ;   % labor tax revenue to GDP ratio
    pi_ss   = 1     ;
    Rss     = 1/beta*pi_ss ;

    save Dynare//para_file_simple_model beta varphi lambda s_Y b_Y pi_ss Rss ;

    LRss    = 0.3  ;
    Yss     = (1-lambda)*LRss ;
    CRss    = (1-s_Y-g_Y)/(1-lambda)*Yss ;
    wss     = 1 ;
    chi     = wss/(LRss^varphi*CRss) ;
    bss     = b_Y*Yss ;
    sss     = s_Y*Yss ;
    gss     = g_Y*Yss ;
    CHss    = 1/lambda*sss ;
    Lss     = LRss*(1-lambda) ;
    tauss   = sss - (1-1/beta)*bss + gss ;

    save Dynare//ss_initial_simple_model Yss CRss CHss wss gss chi bss sss LRss Lss tauss ;
    
    
    %% Monetary Regime: Tax adjustment
    phi     = 1.5       ;   % Taylor rule
    psi     = 0.1       ;   
    psi_g   = 0.0  ;
    save Dynare//para_file_simple_model phi psi psi_g -append ;
    
    cd Dynare
    dynare Model_Dynare_G noclearall ;
    cd ..

    cR = CRss./(beta_s.*realR);
    cH = 1/lambda*s ;
    y = (1-lambda)*cR + s + g ;
    lR = cR + 1/(1-lambda)*s ;

    var = [pi y s g tau] ;

    var_ss = var(1,:) ;

    for k = 1:5
        var(:,k) = (var(:,k)./var_ss(k)-1)*100 ;
    end
    var = var(2:end,:) ;


    %% Monetary Regime: Government spending adjustment (psi_g = -0.05)
    phi     = 1.5       ;   % Taylor rule
    psi     = 0.0       ;   
    psi_g   =-0.05  ;
    save Dynare//para_file_simple_model phi psi psi_g -append ;

    s_shock_values = [0.01 0 0] ;
    beta_shock_values = [0 0 0] ;
    g_shock_values = [0 0 0] ;
    save Dynare//shock_file s_shock_values beta_shock_values g_shock_values tab_light_purple;

    cd Dynare
    dynare Model_Dynare_G noclearall ;
    cd ..

    cR = CRss./(beta_s.*realR);
    cH = 1/lambda*s ;
    y = (1-lambda)*cR + s + g ;
    lR = cR + 1/(1-lambda)*s ;

    var_g = [pi y s g tau] ;

    for k = 1:5
        var_g(:,k) = (var_g(:,k)./var_ss(k)-1)*100 ;
    end
    var_g = var_g(2:end,:) ;

    
    %% Monetary Regime: Government spending adjustment (psi_g = -0.1)
    phi     = 1.5       ;   % Taylor rule
    psi     = 0.0       ;   
    psi_g   =-0.1  ;
    save Dynare//para_file_simple_model phi psi psi_g -append ;

    cd Dynare
    dynare Model_Dynare_G noclearall ;
    cd ..

    cR = CRss./(beta_s.*realR);
    cH = 1/lambda*s ;
    y = (1-lambda)*cR + s + g ;
    lR = cR + 1/(1-lambda)*s ;

    var_g_1 = [pi y s g tau] ;

    for k = 1:5
        var_g_1(:,k) = (var_g_1(:,k)./var_ss(k)-1)*100 ;
    end
    var_g_1 = var_g_1(2:end,:) ;


    %% Monetary Regime: Government spending adjustment (psi_g = -0.5)
    phi     = 1.5       ;   % Taylor rule
    psi     = 0.0       ;   
    psi_g   =-0.2  ;
    save Dynare//para_file_simple_model phi psi psi_g -append ;

    cd Dynare
    dynare Model_Dynare_G noclearall ;
    cd ..

    cR = CRss./(beta_s.*realR);
    cH = 1/lambda*s ;
    y = (1-lambda)*cR + s + g ;
    lR = cR + 1/(1-lambda)*s ;

    var_g_5 = [pi y s g tau] ;

    for k = 1:5
        var_g_5(:,k) = (var_g_5(:,k)./var_ss(k)-1)*100 ;
    end
    var_g_5 = var_g_5(2:end,:) ;


    %%
    Short_Horizon = 4 ;

    fig1 = figure;
    for i = 1:5
        subplot(2,5,i)
        plot(0:Short_Horizon,var(1:Short_Horizon+1,i),lp{1},'Color',tab_blue,'linewidth',1.5) ; hold on
        plot(0:Short_Horizon,var_g(1:Short_Horizon+1,i),lp{2},'Color',tab_red,'linewidth',1.5) ; hold on
        plot(0:Short_Horizon,var_g_1(1:Short_Horizon+1,i),lp{3},'Color',tab_green,'linewidth',1.5) ; hold on
        plot(0:Short_Horizon,var_g_5(1:Short_Horizon+1,i),lp{4},'Color',tab_orange,'linewidth',1.5) ; hold on

        set(gca,'Xcolor',[0 0 0],'FontSize',7,'FontName','Times New Roman',...
            'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
        hh = gca ;
        hh.YBaseline.Visible = 'on'  ;

        title(var_fig_names{i},'Interpreter','Latex','FontSize',10) ;
        if i == 1
        ylabel('percent','Interpreter','Latex','FontSize',8) ;
        end
        xlabel('Time','Interpreter','Latex','FontSize',8) ;
    end
    hSub = subplot(2,5,6:10) ;
    plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2); 
    plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2); hold on ; plot(1,NaN,lp{4},'Color',tab_orange,'LineWidth',2);
    set(hSub, 'Visible', 'off');
    h = legend(hSub,'Tax Adj','Govt Spending Adj ($\psi_g=-0.05$)',...
                    'Govt Spending Adj ($\psi_g=-0.1$)','Govt Spending Adj ($\psi_g=-0.2$)'...
                   ,'Orientation','Horizontal','NumColumns',2);
    h.FontSize = 8 ;
    h.Interpreter = 'latex';
    h.Location = 'northoutside' ;

    set(fig1,'Units','Inches');
    pos = get(fig1,'Position');
    set(fig1,'PaperPositionMode','auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
    fig1.PaperUnits='inches';
    fig1.PaperPosition=[0 0 6.5 3.5];
    if varphi == 0
    print('-dpng','..\\Output_Figure\\Online_Appendix_Figure_B6.png')  ;
    print('-depsc','..\\Output_Figure\\Online_Appendix_Figure_B6.eps')  ;
    else
    print('-dpng','..\\Output_Figure\\Online_Appendix_Figure_B5.png')  ;
    print('-depsc','..\\Output_Figure\\Online_Appendix_Figure_B5.eps')  ;
    end

end

%% Delte Dynare Subfiles
cd Dynare
delete Model_Dynare_G.log para_file_simple_model.mat shock_file.mat ss_initial_simple_model.mat;
rmdir('+Model_Dynare_G','s'); rmdir('Model_Dynare_G','s');
cd ..
