clear; clc; close all;

%% ************************************************************************ 
%   Alternative Transfer Calibration (Online_Appendix Tables C.2 and C.3)
%  ************************************************************************
for ii = 1:4

    Initialization ;
    FindSS ;

    if ii == 1
    % Small transfers: Excluding one-time tax rebates (0.157)
    xi_shock_values = [-0.0577644365032495	-0.2061299958871330	-0.2013695452521850];
    yH_shock_values = [-0.0451876555535828	-0.0120937562501984	0.0227727466646454];
    lH_shock_values = [-0.0772337125169913	0.1792468081903500	0.1768198580382000];
    t_values    = [0.157/(1+beta+beta^2) 0.157/(1+beta+beta^2) 0.157/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    t_values2   = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    elseif ii == 2
    % Small transfers: Excluding UIB (0.167)
    xi_shock_values = [-0.0585428910975940	-0.2070008272733350	-0.2022869171672120];
    yH_shock_values = [-0.0449728889225871	-0.0117943191882143	0.0230570877273861];
    lH_shock_values = [-0.0783884524255600	0.1780141621309460	0.1757890602639800];
    t_values    = [0.167/(1+beta+beta^2) 0.167/(1+beta+beta^2) 0.167/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    t_values2   = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    elseif ii == 3
    % Transfers to both Ricardian and HTM Households
    xi_shock_values = [-0.0598218237004226 -0.208436221228617 -0.203999597147787];
    yH_shock_values = [-0.0445396971283065 -0.0111623929143944 0.0236996205047401];
    lH_shock_values = [-0.080229109212912 0.175977070962509 0.174283910033559];
    t_values    = [0.158/(1+beta+beta^2) 0.158/(1+beta+beta^2) 0.158/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    t_values2   = transfer_ss*[0.110/(1+beta+beta^2) 0.110/(1+beta+beta^2) 0.110/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    xi2     = lambda ;
    save Dynare//para_file xi2 -append ;
    elseif ii == 4
    % Transfer distribution starting from April 2020
    xi_shock_values = [-0.058775883463035 -0.220052175618371 -0.216181614854866];
    yH_shock_values = [-0.0428885990961906 -0.00792713784983943 0.0269829776500575];
    lH_shock_values = [-0.0779248249083929 0.159184135389434 0.160062621898437];
    t_values    = [3/5*0.268/(1+beta+beta^2) 6/5*0.268/(1+beta+beta^2) 6/5*0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    t_values2   = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    end
    
    save Dynare//shock_file_default lH_shock_values yH_shock_values xi_shock_values

    %% Monetary Regime
    psi_b   = 0.0/bss ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    transfer_values2= [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values transfer_values2 ;

    cd Dynare ;
        if ii == 3
            dynare Baseline_ZLB_Rtransfer noclearall
        else
            dynare Baseline_ZLB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
              (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
              (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

    M_var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
           S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
           wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_AMPF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_R(1) = (util_R(1)) ;
    w_util_AMPF_H(1) = (util_H(1)) ;
    mu_AMPF_R(1) = 0 ;
    mu_AMPF_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_R(k) = util_R(k) ;
        w_util_AMPF_H(k) = util_H(k) ;
        else
        w_util_AMPF_R(k) = w_util_AMPF_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_H(k) = w_util_AMPF_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_H(k) - util_H(1)) -1)*100 ;
    end


    %% Fiscal Regime
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    transfer_values2= [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values transfer_values2 -append ;

    cd Dynare ;
        if ii == 3
            dynare Baseline_ZLB_Rtransfer noclearall
        else
            dynare Baseline_ZLB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_PMAF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_R(1) = (util_R(1)) ;
    w_util_PMAF_H(1) = (util_H(1)) ;
    mu_PMAF_R(1) = 0 ;
    mu_PMAF_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_R(k) = util_R(k) ;
        w_util_PMAF_H(k) = util_H(k) ;
        else
        w_util_PMAF_R(k) = w_util_PMAF_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_H(k) = w_util_PMAF_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_H(k) - util_H(1)) -1)*100 ;
    end


    %% Monetary Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = t_values;
    transfer_values2= t_values2;
    save Dynare//shock_file transfer_values transfer_values2 -append ;

    cd Dynare ;
        if ii == 3
            dynare Baseline_ZLB_Rtransfer noclearall
        else
            dynare Baseline_ZLB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
              (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
              (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

    M_var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_AMPF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_t3_R(1) = (util_R(1)) ;
    w_util_AMPF_t3_H(1) = (util_H(1)) ;
    mu_AMPF_t3_R(1) = 0 ;
    mu_AMPF_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_t3_R(k) = util_R(k) ;
        w_util_AMPF_t3_H(k) = util_H(k) ;
        else
        w_util_AMPF_t3_R(k) = w_util_AMPF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_t3_H(k) = w_util_AMPF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_H(k) - util_H(1)) -1)*100 ;
    end

    var_transfer_t3 = M_var_transfer_t3 ;
    var_ss = var_transfer_t3(1,:) ;
    for k = 1:30
        if k == 13
            var_transfer_t3(:,13) = (var_transfer_t3(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var_transfer_t3(:,k) = (var_transfer_t3(:,k)./var_ss(k)-1)*100 ;
        end
    end

    gdp1q = (c(1)+c(2)/2) ; 
    gdp2q = (c(3)+c(2)/2) ;
    gdp3q = (c(4)+c(5)/2) ;

    L_H     = round(target(1:3)',2) ;
    L_R     = round(target(4:6)',2) ;
    Pi_H    = round(target(7:9)',2) ;
    Pi_R    = round([(pi_R(2)-1) (pi_R(2)*pi_R(3)-1) (pi_R(2)*pi_R(3)*pi_R(4)-1)]'*100,2) ;
    C_H     = round(var_transfer_t3(2:4,2),2) ;
    C_R     = round(var_transfer_t3(2:4,1),2) ;
    C       = round(var_transfer_t3(2:4,7),2) ;
    GDP     = round([(gdp2q/gdp1q-1)*100;(gdp3q/gdp1q-1)*100;0],2) ;
    Online_Appendix_Table_C1 = {'April','June','August'}' ;
    Table_Calibration_withT = table(Online_Appendix_Table_C1,L_H,L_R,Pi_H,Pi_R,C_H,C_R,C,GDP) ;


    %% Fiscal Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = t_values;
    transfer_values2= t_values2;
    save Dynare//shock_file transfer_values transfer_values2 -append ;

    cd Dynare ;
        if ii == 3
            dynare Baseline_ZLB_Rtransfer noclearall
        else
            dynare Baseline_ZLB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_PMAF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_t3_R(1) = (util_R(1)) ;
    w_util_PMAF_t3_H(1) = (util_H(1)) ;
    mu_PMAF_t3_R(1) = 0 ;
    mu_PMAF_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_t3_R(k) = util_R(k) ;
        w_util_PMAF_t3_H(k) = util_H(k) ;
        else
        w_util_PMAF_t3_R(k) = w_util_PMAF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_t3_H(k) = w_util_PMAF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_H(k) - util_H(1)) -1)*100 ;
    end


    %% Calculate Multipliers
    L = length(M_var_transfer_t3(2:end,1)) ;
    betas = (beta.^(0:1:L-1))' ;

    tmp = M_var_transfer_t3(2:end,28) ~= M_var(2:end,28) ;
    temp_y = betas.*(M_var_transfer_t3(2:end,7) - M_var(2:end,7)) ;
    temp_yr= betas.*(M_var_transfer_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr= betas.*(M_var_transfer_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch= betas.*(M_var_transfer_t3(2:end,2) - M_var(2:end,2)) ;
    if ii == 3
    temp_t = betas.*(M_var_transfer_t3(2:end,28) + transfer_ss*(0.110/(1+beta+beta^2))*tmp - M_var(2:end,28)) ;
    else
    temp_t = betas.*(M_var_transfer_t3(2:end,28) - M_var(2:end,28)) ;
    end
    temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var(2:end,7)) ;
    temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var(2:end,2)) ;
    temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var(2:end,28)) ;

    for i = 1:length(temp_y)
        M_PVm_y(i,1) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,1) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,1) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,1) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,1) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,1) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,1) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,1) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
    end

    % Multipliers
    M_y  = round([M_PVm_y([1 24],1)],3) ;
    M_yr = round([M_PVm_yr([1 24],1)],3) ;
    M_cr = round([M_PVm_cr([1 24],1)],3) ;
    M_ch = round([M_PVm_ch([1 24],1)],3) ;
    F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
    F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
    F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
    F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;

    % Welfares
    W_long_M    = round([welfare_AMPF_R_t3-welfare_AMPF_R ; welfare_AMPF_H_t3-welfare_AMPF_H],3) ;
    W_long_F    = round([welfare_PMAF_R_t3-welfare_AMPF_R ; welfare_PMAF_H_t3-welfare_AMPF_H],3) ;
    W_short_M   = round([mu_AMPF_t3_R(5)-mu_AMPF_R(5) ; mu_AMPF_t3_H(5)-mu_AMPF_H(5)],3) ;
    W_short_F   = round([mu_PMAF_t3_R(5)-mu_AMPF_R(5) ; mu_PMAF_t3_H(5)-mu_AMPF_H(5)],3) ;

    if ii == 1
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C2_A = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_A = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C3_A = table(Panel_A,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 2
        Panel_B = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C2_B = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_B = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C3_B = table(Panel_B,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 3
        Panel_C = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C2_C = table(Panel_C,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_C = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C3_C = table(Panel_C,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 4
        Panel_D = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C2_D = table(Panel_D,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_D = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C3_D = table(Panel_D,W_long_M,W_short_M,W_long_F,W_short_F) ;
    end

end

%%
clc ;
disp('    =================================================')
disp('    ***      Online_Appendix Table C.2. Multipliers      ***')
disp('    =================================================')
disp(Online_Appendix_Table_C2_A);
disp(Online_Appendix_Table_C2_B);
disp(Online_Appendix_Table_C2_C);
disp(Online_Appendix_Table_C2_D);
disp(' ')
writetable(Online_Appendix_Table_C2_A,'..\Output_Table\Online_Appendix_Table_C2.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C2_B,'..\Output_Table\Online_Appendix_Table_C2.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C2_C,'..\Output_Table\Online_Appendix_Table_C2.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C2_D,'..\Output_Table\Online_Appendix_Table_C2.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 

disp('    ===================================================')
disp('    ***      Online_Appendix Table C.3. Welfare Gains      ***')
disp('    ===================================================')
disp(Online_Appendix_Table_C3_A);
disp(Online_Appendix_Table_C3_B);
disp(Online_Appendix_Table_C3_C);
disp(Online_Appendix_Table_C3_D);
disp(' ')
writetable(Online_Appendix_Table_C3_A,'..\Output_Table\Online_Appendix_Table_C3.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C3_B,'..\Output_Table\Online_Appendix_Table_C3.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C3_C,'..\Output_Table\Online_Appendix_Table_C3.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C3_D,'..\Output_Table\Online_Appendix_Table_C3.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 

%% Delte Dynare Subfiles
cd Dynare
delete Baseline_ZLB.log Baseline_ZLB_Rtransfer.log ;
delete para_file.mat shock_file.mat shock_file_default.mat ss_initial.mat;
rmdir('+Baseline_ZLB','s'); rmdir('Baseline_ZLB','s');
rmdir('+Baseline_ZLB_Rtransfer','s'); rmdir('Baseline_ZLB_Rtransfer','s');
cd ..
