clear; clc; close all;

%% ************************************************************************ 
%   Including Government Spending (Online_Appendix Tables C.4-C.7)
%  ************************************************************************
for ii = 1:2
    Initialization ;
    alpha_G = alpha_R;
    g_Y     = 15.0/100  ;   % labor tax revenue to GDP ratio
    rho_g   = 0.0  ;
    
    save Dynare//para_file alpha_G g_Y rho_g -append
    FindSS_G ;

    if ii == 1
        % Labor tax adjustment
        xi_shock_values = [-0.0842975524225889 -0.281164488782323 -0.293418193335646];
        yH_shock_values = [-0.0254675610512184 0.0198538980905219 0.0558770912429586];
        lH_shock_values = [-0.0835303843393911 0.170305277294564 0.183186236746262];
    elseif ii == 2
        % Government spending adjustment
        xi_shock_values = [-0.084542686884765 -0.279635344481429 -0.302771605703787];
        yH_shock_values = [-0.0201596198985968 0.0288153536582648 0.066883459505088];
        lH_shock_values = [-0.0785869186623232 0.171786861587661 0.192937488298145];
    end
    
    save Dynare//shock_file_default lH_shock_values yH_shock_values xi_shock_values
    
    %% Monetary Regime
    psi_b   = 0.0/bss ;   % Lump-sum tax rule
    if ii == 1
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    psi_g   = 0.0/bss   ;   % spending rule
    else
    psi_LR  = 0.0/bss   ;   % labor tax rate rule
    psi_g   = -0.1/bss   ;   % spending rule
    end
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy psi_g -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    g_shock_values  = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values g_shock_values ;

    cd Dynare ;
        dynare Baseline_ZLB_G noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    y = c + Q_G.*g;

    target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
              (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
              (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

    M_var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
           S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
           wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H y g gR gH] ;

    welfare_AMPF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_R(1) = (util_R(1)) ;
    w_util_AMPF_H(1) = (util_H(1)) ;
    mu_AMPF_R(1) = 0 ;
    mu_AMPF_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_R(k) = util_R(k) ;
        w_util_AMPF_H(k) = util_H(k) ;
        else
        w_util_AMPF_R(k) = w_util_AMPF_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_H(k) = w_util_AMPF_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_H(k) - util_H(1)) -1)*100 ;
    end


    %% Fiscal Regime
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    psi_g   = 0.0   ;   % spending rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy psi_g -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    g_shock_values  = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values g_shock_values -append ;

    cd Dynare ;
        dynare Baseline_ZLB_G noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    y = c + Q_G.*g;

    M_var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H y g gR gH] ;

    welfare_PMAF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_R(1) = (util_R(1)) ;
    w_util_PMAF_H(1) = (util_H(1)) ;
    mu_PMAF_R(1) = 0 ;
    mu_PMAF_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_R(k) = util_R(k) ;
        w_util_PMAF_H(k) = util_H(k) ;
        else
        w_util_PMAF_R(k) = w_util_PMAF_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_H(k) = w_util_PMAF_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_H(k) - util_H(1)) -1)*100 ;
    end


    %% Monetary Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    if ii == 1
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    psi_g   = 0.0/bss   ;   % spending rule
    else
    psi_LR  = 0.0/bss   ;   % labor tax rate rule
    psi_g   = -0.1/bss   ;   % spending rule
    end
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy psi_g -append ;

    transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    g_shock_values  = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values g_shock_values -append ;

    cd Dynare ;
        dynare Baseline_ZLB_G noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    y = c + Q_G.*g;

    target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
              (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
              (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

    M_var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H y g gR gH] ;

    welfare_AMPF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_t3_R(1) = (util_R(1)) ;
    w_util_AMPF_t3_H(1) = (util_H(1)) ;
    mu_AMPF_t3_R(1) = 0 ;
    mu_AMPF_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_t3_R(k) = util_R(k) ;
        w_util_AMPF_t3_H(k) = util_H(k) ;
        else
        w_util_AMPF_t3_R(k) = w_util_AMPF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_t3_H(k) = w_util_AMPF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_H(k) - util_H(1)) -1)*100 ;
    end

    var_transfer_t3 = M_var_transfer_t3 ;
    var_ss = var_transfer_t3(1,:) ;
    for k = 1:30
        if k == 13
            var_transfer_t3(:,13) = (var_transfer_t3(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var_transfer_t3(:,k) = (var_transfer_t3(:,k)./var_ss(k)-1)*100 ;
        end
    end

    gdp1q = (c(1)+c(2)/2) ; 
    gdp2q = (c(3)+c(2)/2) ;
    gdp3q = (c(4)+c(5)/2) ;

    L_H     = round(target(1:3)',2) ;
    L_R     = round(target(4:6)',2) ;
    Pi_H    = round(target(7:9)',2) ;
    Pi_R    = round([(pi_R(2)-1) (pi_R(2)*pi_R(3)-1) (pi_R(2)*pi_R(3)*pi_R(4)-1)]'*100,2) ;
    C_H     = round(var_transfer_t3(2:4,2),2) ;
    C_R     = round(var_transfer_t3(2:4,1),2) ;
    C       = round(var_transfer_t3(2:4,7),2) ;
    GDP     = round([(gdp2q/gdp1q-1)*100;(gdp3q/gdp1q-1)*100;0],2) ;
    Online_Appendix_Table_C1 = {'April','June','August'}' ;
    Table_Calibration_withT = table(Online_Appendix_Table_C1,L_H,L_R,Pi_H,Pi_R,C_H,C_R,C,GDP) ;


    %% Fiscal Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    psi_g   = 0.0   ;   % spending rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy psi_g -append ;

    transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    g_shock_values  = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values g_shock_values -append ;

    cd Dynare ;
        dynare Baseline_ZLB_G noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    y = c + Q_G.*g;

    M_var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H y g gR gH] ;

    welfare_PMAF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_t3_R(1) = (util_R(1)) ;
    w_util_PMAF_t3_H(1) = (util_H(1)) ;
    mu_PMAF_t3_R(1) = 0 ;
    mu_PMAF_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_t3_R(k) = util_R(k) ;
        w_util_PMAF_t3_H(k) = util_H(k) ;
        else
        w_util_PMAF_t3_R(k) = w_util_PMAF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_t3_H(k) = w_util_PMAF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_H(k) - util_H(1)) -1)*100 ;
    end


    %% Monetary Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    if ii == 1
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    psi_g   = 0.0/bss   ;   % spending rule
    else
    psi_LR  = 0.0/bss   ;   % labor tax rate rule
    psi_g   = -0.1/bss   ;   % spending rule
    end
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy psi_g -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    g_shock_values  = transfer_ss/Gss*[0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values g_shock_values -append ;

    cd Dynare ;
        dynare Baseline_ZLB_G noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    y = c + Q_G.*g;

    M_var_Gspend_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H y g gR gH] ;

    welfare_AMPF_R_Gspend_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H_Gspend_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_Gspend_t3_R(1) = (util_R(1)) ;
    w_util_AMPF_Gspend_t3_H(1) = (util_H(1)) ;
    mu_AMPF_Gspend_t3_R(1) = 0 ;
    mu_AMPF_Gspend_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_Gspend_t3_R(k) = util_R(k) ;
        w_util_AMPF_Gspend_t3_H(k) = util_H(k) ;
        else
        w_util_AMPF_Gspend_t3_R(k) = w_util_AMPF_Gspend_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_Gspend_t3_H(k) = w_util_AMPF_Gspend_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_Gspend_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_Gspend_t3_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_Gspend_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_Gspend_t3_H(k) - util_H(1)) -1)*100 ;
    end

    var_Gspend_t3 = M_var_Gspend_t3 ;
    var_ss = var_Gspend_t3(1,:) ;
    for k = 1:30
        if k == 13
            var_Gspend_t3(:,13) = (var_Gspend_t3(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var_Gspend_t3(:,k) = (var_Gspend_t3(:,k)./var_ss(k)-1)*100 ;
        end
    end


    %% Fiscal Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    psi_g   = 0.0   ;   % spending rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy psi_g -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    g_shock_values  = transfer_ss/Gss*[0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values g_shock_values -append ;

    cd Dynare ;
        dynare Baseline_ZLB_G noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    y = c + Q_G.*g;

    M_var_PMAF_Gspend_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H y g gR gH] ;

    welfare_PMAF_R_Gspend_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H_Gspend_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_Gspend_t3_R(1) = (util_R(1)) ;
    w_util_PMAF_Gspend_t3_H(1) = (util_H(1)) ;
    mu_PMAF_Gspend_t3_R(1) = 0 ;
    mu_PMAF_Gspend_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_Gspend_t3_R(k) = util_R(k) ;
        w_util_PMAF_Gspend_t3_H(k) = util_H(k) ;
        else
        w_util_PMAF_Gspend_t3_R(k) = w_util_PMAF_Gspend_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_Gspend_t3_H(k) = w_util_PMAF_Gspend_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_Gspend_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_Gspend_t3_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_Gspend_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_Gspend_t3_H(k) - util_H(1)) -1)*100 ;
    end



    %% Calculate Multipliers
    L = length(M_var_transfer_t3(2:end,1)) ;
    betas = (beta.^(0:1:L-1))' ;

    temp_y = betas.*(M_var_transfer_t3(2:end,7) - M_var(2:end,7)) ;
    temp_yr= betas.*(M_var_transfer_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr= betas.*(M_var_transfer_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch= betas.*(M_var_transfer_t3(2:end,2) - M_var(2:end,2)) ;
    temp_t = betas.*(M_var_transfer_t3(2:end,28) - M_var(2:end,28)) ;
    temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var(2:end,7)) ;
    temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var(2:end,2)) ;
    temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var(2:end,28)) ;

    for i = 1:length(temp_y)
        M_PVm_y(i,1) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,1) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,1) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,1) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,1) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,1) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,1) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,1) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
    end

    % Multipliers
    M_y  = round([M_PVm_y([1 24],1)],3) ;
    M_yr = round([M_PVm_yr([1 24],1)],3) ;
    M_cr = round([M_PVm_cr([1 24],1)],3) ;
    M_ch = round([M_PVm_ch([1 24],1)],3) ;
    F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
    F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
    F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
    F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;

    % Welfares
    W_long_M    = round([welfare_AMPF_R_t3-welfare_AMPF_R ; welfare_AMPF_H_t3-welfare_AMPF_H],3) ;
    W_long_F    = round([welfare_PMAF_R_t3-welfare_AMPF_R ; welfare_PMAF_H_t3-welfare_AMPF_H],3) ;
    W_short_M   = round([mu_AMPF_t3_R(5)-mu_AMPF_R(5) ; mu_AMPF_t3_H(5)-mu_AMPF_H(5)],3) ;
    W_short_F   = round([mu_PMAF_t3_R(5)-mu_AMPF_R(5) ; mu_PMAF_t3_H(5)-mu_AMPF_H(5)],3) ;

    if ii == 1
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C4_A = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_A = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C5_A = table(Panel_A,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 2
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C6_A = table(Panel_A,M_y,M_yr,M_cr,M_ch) ;
        Panel_B = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C6_B = table(Panel_B,W_long_M,W_short_M) ;
    end


    temp_c = betas.*(M_var_Gspend_t3(2:end,7) - M_var(2:end,7)) ;
    temp_y = betas.*(M_var_Gspend_t3(2:end,31) - M_var(2:end,31)) ;
    temp_yr= betas.*(M_var_Gspend_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr= betas.*(M_var_Gspend_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch= betas.*(M_var_Gspend_t3(2:end,2) - M_var(2:end,2)) ;
    temp_g = betas.*(M_var_Gspend_t3(2:end,32) - M_var(2:end,32)) ;
    temp_c_PMAF_mbase = betas.*(M_var_PMAF_Gspend_t3(2:end,7) - M_var(2:end,7)) ;
    temp_y_PMAF_mbase = betas.*(M_var_PMAF_Gspend_t3(2:end,31) - M_var(2:end,31)) ;
    temp_yr_PMAF_mbase = betas.*(M_var_PMAF_Gspend_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr_PMAF_mbase = betas.*(M_var_PMAF_Gspend_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch_PMAF_mbase = betas.*(M_var_PMAF_Gspend_t3(2:end,2) - M_var(2:end,2)) ;
    temp_g_PMAF_mbase = betas.*(M_var_PMAF_Gspend_t3(2:end,32) - M_var(2:end,32)) ;

    for i = 1:length(temp_y)
        M_PVm_c(i,1) = sum(temp_c(1:i))/sum(temp_g(1:i)) ;
        M_PVm_y(i,1) = sum(temp_y(1:i))/sum(temp_g(1:i)) ;
        M_PVm_yr(i,1) = sum(temp_yr(1:i))/sum(temp_g(1:i)) ;
        M_PVm_cr(i,1) = sum(temp_cr(1:i))/sum(temp_g(1:i)) ;
        M_PVm_ch(i,1) = sum(temp_ch(1:i))/sum(temp_g(1:i)) ;
        M_PVm_y_PMAF_mbase(i,1) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_g(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,1) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_g(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,1) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_g(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,1) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_g(1:i)) ;
    end

    % Multipliers
    M_y  = round([M_PVm_y([1 24],1)],3) ;
    M_yr = round([M_PVm_yr([1 24],1)],3) ;
    M_cr = round([M_PVm_cr([1 24],1)],3) ;
    M_ch = round([M_PVm_ch([1 24],1)],3) ;
    F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
    F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
    F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
    F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;

    % Welfares
    W_long_M    = round([welfare_AMPF_R_Gspend_t3-welfare_AMPF_R ; welfare_AMPF_H_Gspend_t3-welfare_AMPF_H],3) ;
    W_long_F    = round([welfare_PMAF_R_Gspend_t3-welfare_AMPF_R ; welfare_PMAF_H_Gspend_t3-welfare_AMPF_H],3) ;
    W_short_M   = round([mu_AMPF_Gspend_t3_R(5)-mu_AMPF_R(5) ; mu_AMPF_Gspend_t3_H(5)-mu_AMPF_H(5)],3) ;
    W_short_F   = round([mu_PMAF_Gspend_t3_R(5)-mu_AMPF_R(5) ; mu_PMAF_Gspend_t3_H(5)-mu_AMPF_H(5)],3) ;

    if ii == 1
        Panel_B = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C4_B = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_B = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C5_B = table(Panel_B,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 2
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C7   = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    end
end

%%
clc ;
disp('    =================================================')
disp('    ***      Online_Appendix Table C.4. Multipliers      ***')
disp('    =================================================')
disp(Online_Appendix_Table_C4_A);
disp(Online_Appendix_Table_C4_B);
disp(' ');
writetable(Online_Appendix_Table_C4_A,'..\Output_Table\Online_Appendix_Table_C4.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C4_B,'..\Output_Table\Online_Appendix_Table_C4.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    ===================================================')
disp('    ***      Online_Appendix Table C.5. Welfare Gains      ***')
disp('    ===================================================')
disp(Online_Appendix_Table_C5_A);
disp(Online_Appendix_Table_C5_B);
disp(' ');
writetable(Online_Appendix_Table_C5_A,'..\Output_Table\Online_Appendix_Table_C5.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C5_B,'..\Output_Table\Online_Appendix_Table_C5.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    =======================================================')
disp('    ***      Online_Appendix Table C.6. Gvnt Spending Adj      ***')
disp('    =======================================================')
disp(Online_Appendix_Table_C6_A);
disp(Online_Appendix_Table_C6_B);
disp(' ');
writetable(Online_Appendix_Table_C6_A,'..\Output_Table\Online_Appendix_Table_C6.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C6_B,'..\Output_Table\Online_Appendix_Table_C6.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    ======================================================================')
disp('    ***      Online_Appendix Table C.7. Gvnt Spending Adj: G-Multipliers      ***')
disp('    ======================================================================')
disp(Online_Appendix_Table_C7);
disp(' ');
writetable(Online_Appendix_Table_C7,'..\Output_Table\Online_Appendix_Table_C7.csv','WriteRowNames',true);

%% Delte Dynare Subfiles
cd Dynare
delete Baseline_ZLB_G.log ;
delete para_file.mat shock_file.mat shock_file_default.mat ss_initial.mat;
rmdir('+Baseline_ZLB_G','s'); rmdir('Baseline_ZLB_G','s');
cd ..
