clear; clc; close all;

%% ************************************************************************ 
%   Money-in-utility (Online_Appendix Table C.8)
%   Inflationary shocks (Online_Appendix Tables C.9 and C.10, Online_Appendix Figure C.2)
%   Higher initial debt to GDP (Online_Appendix Tables C.11, C.12 and C.13)
%  ************************************************************************
for ii = 1:8
    Initialization ;
    t_values    = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    
    if ii == 1
        % Money-in-utility
        nu      = 0.94  ;   % weight on consumption
        eta     = 0.40  ;   % ES b/w consumption and real money balance
        save Dynare//para_file nu eta -append
        FindSS_MIU ;

        pi_shock_values = [0 0 0 0   0 0 0 0 0 0 0 0] ;
        xi_shock_values = [0 0 0];
        yH_shock_values = [0 0 0];
        lH_shock_values = [0 0 0];
    elseif ii == 2
        % Inflationary shocks: 
        rho_infl = 0.5 ;
        save Dynare//para_file rho_infl -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0   0 0 0 0 0 0 0 0] ;
        xi_shock_values = [-0.0664554546546023	-0.2158402772618420	-0.2116002099700470];
        yH_shock_values = [-0.0427695295662761	-0.0087350940445975	0.0259595483391810];
        lH_shock_values = [-0.0897949884559149	0.1657476479089390	0.1655317365515420];
    elseif ii == 3
        % Inflationary shocks: 
        rho_infl = 0.5 ;
        save Dynare//para_file rho_infl -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0.1 0 0 0 0 0 0 0 0] ;
        xi_shock_values = [-0.0729426587318509 -0.225068530054505 -0.221036427278591];
        yH_shock_values = [-0.0461841142997954 -0.014637027704681 0.018968158307076];
        lH_shock_values = [-0.0999860442642275 0.165613499540177 0.165642549836542];
    elseif ii == 4
        % Inflationary shocks: 
        rho_infl = 0.5 ;
        save Dynare//para_file rho_infl -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0.2 0 0 0 0 0 0 0 0] ;
        xi_shock_values = [-0.0768878549794726 -0.231848198853318 -0.217466749302407];
        yH_shock_values = [-0.050497787002385 -0.0221303508929222 0.00978316843687027];
        lH_shock_values = [-0.111585204512629 0.165379861256821 0.154768927853339];
    elseif ii == 5
        % Above steady-state debt-to-gdp: 
        hist_in = 1.1 ;
        save Dynare//para_file hist_in -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0   0 0 0 0 0 0 0 0] ;
        xi_shock_values = [-0.0683496974653048 -0.217134326670541 -0.189520942117563];
        yH_shock_values = [-0.0512657425086554 -0.0237122567134909 0.00712268536650289];
        lH_shock_values = [-0.0984042038778523 0.163330728196891 0.138779247759015];
    elseif ii == 6
        % Above steady-state debt-to-gdp: 
        hist_in = 1.1 ;
        tf_Y    = 14.9/100  ;   % total transfer to GDP ratio
        TL_Y    = 11.7/100  ;   % labor tax revenue to GDP ratio
        b_Y     = 71.3/100  ;   % Debt to GDP ratio
        b_Y     = b_Y*6 ;
        save Dynare//para_file hist_in tf_Y TL_Y b_Y -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0   0 0 0 0 0 0 0 0] ;
        xi_shock_values = [-0.0739374377896679 -0.228707788750778 -0.199937149423107];
        yH_shock_values = [-0.0487831731457572 -0.0197783344793192 0.0110751985197491];
        lH_shock_values = [-0.11668469029176 0.15812887487224 0.138460185516315];
    elseif ii == 7
        % Baseline steady-state debt-to-gdp without COVID shocks
        hist_in = 1.0 ;
        save Dynare//para_file hist_in -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0   0 0 0 0 0 0 0 0] ;
        xi_shock_values = [0 0 0];
        yH_shock_values = [0 0 0];
        lH_shock_values = [0 0 0];
    elseif ii == 8
        % Higher steady-state debt-to-gdp without COVID shocks
        hist_in = 1.0 ;
        tf_Y    = 14.9/100  ;   % total transfer to GDP ratio
        TL_Y    = 11.7/100  ;   % labor tax revenue to GDP ratio
        b_Y     = 71.3/100  ;   % Debt to GDP ratio
        b_Y     = b_Y*6 ;
        save Dynare//para_file hist_in tf_Y TL_Y b_Y -append
        FindSS ;
        
        pi_shock_values = [0 0 0 0   0 0 0 0 0 0 0 0] ;
        xi_shock_values = [0 0 0];
        yH_shock_values = [0 0 0];
        lH_shock_values = [0 0 0];
    end

    save Dynare//shock_file_default lH_shock_values yH_shock_values xi_shock_values pi_shock_values

    %% Monetary Regime
    psi_b   = 0.0/bss ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values ;

    cd Dynare ;
        if ii == 1
        dynare MIU_Baseline_ZLB noclearall
        elseif ii >= 2 && ii <= 4
        dynare Baseline_ZLB_PiShock noclearall
        else
        dynare Baseline_ZLB_HistB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
              (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
              (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

    M_var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
           S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
           wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H] ;
    
    if ii ~= 1
        welfare_AMPF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
        welfare_AMPF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

        w_util_AMPF_R(1) = (util_R(1)) ;
        w_util_AMPF_H(1) = (util_H(1)) ;
        mu_AMPF_R(1) = 0 ;
        mu_AMPF_H(1) = 0 ;
        for k = 2:length(util_R)
            if k == 2
            w_util_AMPF_R(k) = util_R(k) ;
            w_util_AMPF_H(k) = util_H(k) ;
            else
            w_util_AMPF_R(k) = w_util_AMPF_R(k-1) + beta^(k-2)*util_R(k) ;
            w_util_AMPF_H(k) = w_util_AMPF_H(k-1) + beta^(k-2)*util_H(k) ;
            end
            mu_AMPF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_R(k) - util_R(1)) -1)*100 ;
            mu_AMPF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_H(k) - util_H(1)) -1)*100 ;
        end
    end
    
    %% Fiscal Regime
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file transfer_values -append ;

    cd Dynare ;
        if ii == 1
        dynare MIU_Baseline_ZLB noclearall
        elseif ii >= 2 && ii <= 4
        dynare Baseline_ZLB_PiShock noclearall
        else
        dynare Baseline_ZLB_HistB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    if ii ~= 1
        welfare_PMAF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
        welfare_PMAF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

        w_util_PMAF_R(1) = (util_R(1)) ;
        w_util_PMAF_H(1) = (util_H(1)) ;
        mu_PMAF_R(1) = 0 ;
        mu_PMAF_H(1) = 0 ;
        for k = 2:length(util_R)
            if k == 2
            w_util_PMAF_R(k) = util_R(k) ;
            w_util_PMAF_H(k) = util_H(k) ;
            else
            w_util_PMAF_R(k) = w_util_PMAF_R(k-1) + beta^(k-2)*util_R(k) ;
            w_util_PMAF_H(k) = w_util_PMAF_H(k-1) + beta^(k-2)*util_H(k) ;
            end
            mu_PMAF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_R(k) - util_R(1)) -1)*100 ;
            mu_PMAF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_H(k) - util_H(1)) -1)*100 ;
        end
    end

    %% Monetary Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = t_values;
    save Dynare//shock_file transfer_values -append ;

    cd Dynare ;
        if ii == 1
        dynare MIU_Baseline_ZLB noclearall
        elseif ii >= 2 && ii <= 4
        dynare Baseline_ZLB_PiShock noclearall
        else
        dynare Baseline_ZLB_HistB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
              (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
              (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

    M_var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    if ii ~= 1
        welfare_AMPF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
        welfare_AMPF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

        w_util_AMPF_t3_R(1) = (util_R(1)) ;
        w_util_AMPF_t3_H(1) = (util_H(1)) ;
        mu_AMPF_t3_R(1) = 0 ;
        mu_AMPF_t3_H(1) = 0 ;
        for k = 2:length(util_R)
            if k == 2
            w_util_AMPF_t3_R(k) = util_R(k) ;
            w_util_AMPF_t3_H(k) = util_H(k) ;
            else
            w_util_AMPF_t3_R(k) = w_util_AMPF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
            w_util_AMPF_t3_H(k) = w_util_AMPF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
            end
            mu_AMPF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_R(k) - util_R(1)) -1)*100 ;
            mu_AMPF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_H(k) - util_H(1)) -1)*100 ;
        end
    end

    var_transfer_t3 = M_var_transfer_t3 ;
    var_ss = var_transfer_t3(1,:) ;
    for k = 1:30
        if k == 13
            var_transfer_t3(:,13) = (var_transfer_t3(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var_transfer_t3(:,k) = (var_transfer_t3(:,k)./var_ss(k)-1)*100 ;
        end
    end
    var_transfer_t3_seq{ii} = var_transfer_t3 ;
    
    gdp1q = (c(1)+c(2)/2) ; 
    gdp2q = (c(3)+c(2)/2) ;
    gdp3q = (c(4)+c(5)/2) ;

    L_H     = round(target(1:3)',2) ;
    L_R     = round(target(4:6)',2) ;
    Pi_H    = round(target(7:9)',2) ;
    Pi_R    = round([(pi_R(2)-1) (pi_R(2)*pi_R(3)-1) (pi_R(2)*pi_R(3)*pi_R(4)-1)]'*100,2) ;
    C_H     = round(var_transfer_t3(2:4,2),2) ;
    C_R     = round(var_transfer_t3(2:4,1),2) ;
    C       = round(var_transfer_t3(2:4,7),2) ;
    GDP     = round([(gdp2q/gdp1q-1)*100;(gdp3q/gdp1q-1)*100;0],2) ;
    Online_Appendix_Table_C1 = {'April','June','August'}' ;
    Table_Calibration_withT = table(Online_Appendix_Table_C1,L_H,L_R,Pi_H,Pi_R,C_H,C_R,C,GDP) ;


    %% Fiscal Regime with transfer: three period
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;

    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    transfer_values = t_values;
    save Dynare//shock_file transfer_values -append ;

    cd Dynare ;
        if ii == 1
        dynare MIU_Baseline_ZLB noclearall
        elseif ii >= 2 && ii <= 4
        dynare Baseline_ZLB_PiShock noclearall
        else
        dynare Baseline_ZLB_HistB noclearall
        end
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;
       
    if ii ~= 1
        welfare_PMAF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
        welfare_PMAF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

        w_util_PMAF_t3_R(1) = (util_R(1)) ;
        w_util_PMAF_t3_H(1) = (util_H(1)) ;
        mu_PMAF_t3_R(1) = 0 ;
        mu_PMAF_t3_H(1) = 0 ;
        for k = 2:length(util_R)
            if k == 2
            w_util_PMAF_t3_R(k) = util_R(k) ;
            w_util_PMAF_t3_H(k) = util_H(k) ;
            else
            w_util_PMAF_t3_R(k) = w_util_PMAF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
            w_util_PMAF_t3_H(k) = w_util_PMAF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
            end
            mu_PMAF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_R(k) - util_R(1)) -1)*100 ;
            mu_PMAF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_H(k) - util_H(1)) -1)*100 ;
        end
    end

    var_PMAF_transfer_t3 = M_var_PMAF_transfer_t3 ;
    var_ss = var_PMAF_transfer_t3(1,:) ;
    for k = 1:30
        if k == 13
            var_PMAF_transfer_t3(:,13) = (var_PMAF_transfer_t3(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var_PMAF_transfer_t3(:,k) = (var_PMAF_transfer_t3(:,k)./var_ss(k)-1)*100 ;
        end
    end
    var_PMAF_transfer_t3_seq{ii} = var_PMAF_transfer_t3 ;

    %% Calculate Multipliers
    L = length(M_var_transfer_t3(2:end,1)) ;
    betas = (beta.^(0:1:L-1))' ;

    temp_y = betas.*(M_var_transfer_t3(2:end,7) - M_var(2:end,7)) ;
    temp_yr= betas.*(M_var_transfer_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr= betas.*(M_var_transfer_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch= betas.*(M_var_transfer_t3(2:end,2) - M_var(2:end,2)) ;
    temp_t = betas.*(M_var_transfer_t3(2:end,28) - M_var(2:end,28)) ;
    temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var(2:end,7)) ;
    temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var(2:end,8)) ;
    temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var(2:end,1)) ;
    temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var(2:end,2)) ;
    temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var(2:end,28)) ;

    for i = 1:length(temp_y)
        M_PVm_y(i,1) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,1) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,1) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,1) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,1) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,1) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,1) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,1) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
    end

    % Multipliers
    M_y  = round([M_PVm_y([1 24],1)],3) ;
    M_yr = round([M_PVm_yr([1 24],1)],3) ;
    M_cr = round([M_PVm_cr([1 24],1)],3) ;
    M_ch = round([M_PVm_ch([1 24],1)],3) ;
    F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
    F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
    F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
    F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;

    % Welfares
    if ii ~= 1
    W_long_M    = round([welfare_AMPF_R_t3-welfare_AMPF_R ; welfare_AMPF_H_t3-welfare_AMPF_H],3) ;
    W_long_F    = round([welfare_PMAF_R_t3-welfare_AMPF_R ; welfare_PMAF_H_t3-welfare_AMPF_H],3) ;
    W_short_M   = round([mu_AMPF_t3_R(5)-mu_AMPF_R(5) ; mu_AMPF_t3_H(5)-mu_AMPF_H(5)],3) ;
    W_short_F   = round([mu_PMAF_t3_R(5)-mu_AMPF_R(5) ; mu_PMAF_t3_H(5)-mu_AMPF_H(5)],3) ;
    end
    
    if ii == 1
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C8 = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    elseif ii == 3
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C9_A = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_A = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C10_A = table(Panel_A,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 4
        Panel_B = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C9_B = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_B = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C10_B = table(Panel_B,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 5
        Panel_A = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C11_A = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_A = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C12_A = table(Panel_A,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 6
        Panel_B = {'Impact','4-Year'}' ;
        Online_Appendix_Table_C11_B = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        Panel_B = {'Ricardian','HtM'}' ;
        Online_Appendix_Table_C12_B = table(Panel_B,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif ii == 7
        tmp_mat = [M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch] ;
    elseif ii == 8
        tmp_mat2 = [M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch] ;
        tmp_mat3 = [tmp_mat(1,:); tmp_mat2(1,:)] ;
        M_y  = tmp_mat3(:,1);   M_yr = tmp_mat3(:,2);
        M_cr = tmp_mat3(:,3);   M_ch = tmp_mat3(:,4);
        F_y  = tmp_mat3(:,5);   F_yr = tmp_mat3(:,6);
        F_cr = tmp_mat3(:,7);   F_ch = tmp_mat3(:,8);
        Panel_A = {'Baseline','Higher Steady-state debt'}' ;
        Online_Appendix_Table_C13_A = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
        
        tmp_mat4 = [tmp_mat(2,:); tmp_mat2(2,:)] ;
        M_y  = tmp_mat4(:,1);   M_yr = tmp_mat4(:,2);
        M_cr = tmp_mat4(:,3);   M_ch = tmp_mat4(:,4);
        F_y  = tmp_mat4(:,5);   F_yr = tmp_mat4(:,6);
        F_cr = tmp_mat4(:,7);   F_ch = tmp_mat4(:,8);
        Panel_B = {'Baseline','Higher Steady-state debt'}' ;
        Online_Appendix_Table_C13_B = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    end

end

%%
clc ;
disp('    ===================================================================')
disp('    ***      Online_Appendix Table C.8. Money-in-Utility: Multipliers      ***')
disp('    ===================================================================')
disp(Online_Appendix_Table_C8);
disp(' ')
writetable(Online_Appendix_Table_C8,'..\Output_Table\Online_Appendix_Table_C8.csv','WriteRowNames',true);


disp('    ======================================================================')
disp('    ***      Online_Appendix Table C.9. Inflationary shocks: Multipliers      ***')
disp('    ======================================================================')
disp(Online_Appendix_Table_C9_A);
disp(Online_Appendix_Table_C9_B);
disp(' ')
writetable(Online_Appendix_Table_C9_A,'..\Output_Table\Online_Appendix_Table_C9.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C9_B,'..\Output_Table\Online_Appendix_Table_C9.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    ====================================================================')
disp('    ***      Online_Appendix Table C.10. Inflationary shocks: Welfares      ***')
disp('    ====================================================================')
disp(Online_Appendix_Table_C10_A);
disp(Online_Appendix_Table_C10_B);
disp(' ')
writetable(Online_Appendix_Table_C10_A,'..\Output_Table\Online_Appendix_Table_C10.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C10_B,'..\Output_Table\Online_Appendix_Table_C10.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    ===========================================================================')
disp('    ***      Online_Appendix Table C.11. Above Steady-state Debt: Multipliers      ***')
disp('    ===========================================================================')
disp(Online_Appendix_Table_C11_A);
disp(Online_Appendix_Table_C11_B);
disp(' ')
writetable(Online_Appendix_Table_C11_A,'..\Output_Table\Online_Appendix_Table_C11.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C11_B,'..\Output_Table\Online_Appendix_Table_C11.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    =========================================================================')
disp('    ***      Online_Appendix Table C.12. Above Steady-state Debt: Welfares      ***')
disp('    =========================================================================')
disp(Online_Appendix_Table_C12_A);
disp(Online_Appendix_Table_C12_B);
disp(' ')
writetable(Online_Appendix_Table_C12_A,'..\Output_Table\Online_Appendix_Table_C12.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C12_B,'..\Output_Table\Online_Appendix_Table_C12.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    =================================================================================================')
disp('    ***      Online_Appendix Table C.13. Higher Steady-state Debt without COVID Shocks: Multipliers      ***')
disp('    =================================================================================================')
disp(Online_Appendix_Table_C13_A);
disp(Online_Appendix_Table_C13_B);
disp(' ')
writetable(Online_Appendix_Table_C13_A,'..\Output_Table\Online_Appendix_Table_C13.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C13_B,'..\Output_Table\Online_Appendix_Table_C13.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


%% Online_Appendix Figure C.2
figure_index = [1 2 7 8 17 18 13 23 26] ;

fig1 = figure;
for i = 1:9
    j = figure_index(i) ;
    subplot(4,3,i)
    plot(0:Short_Horizon,var_transfer_t3_seq{2}(1:Short_Horizon+1,j),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_transfer_t3_seq{2}(1:Short_Horizon+1,j),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_transfer_t3_seq{3}(1:Short_Horizon+1,j),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_transfer_t3_seq{3}(1:Short_Horizon+1,j),lp{4},'Color',tab_orange,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_transfer_t3_seq{4}(1:Short_Horizon+1,j),lp{5},'Color',tab_purple,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_transfer_t3_seq{4}(1:Short_Horizon+1,j),lp{2},'Color',darkred,'linewidth',2) ; hold on
    axis tight

    set(gca,'Xcolor',[0 0 0],'XTick',0:2:Short_Horizon,'FontSize',7,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'off'  ;

    title(var_fig_names{j},'Interpreter','Latex','FontSize',10) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;

    if i>=7
        xlabel('Time','Interpreter','Latex','FontSize',8) ;
    end
end
hSub = subplot(4,3,10:12) ;
plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; 
plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2) ; 
plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2) ; 
plot(1,NaN,lp{4},'Color',tab_orange,'LineWidth',2); hold on 
plot(1,NaN,lp{5},'Color',tab_purple,'LineWidth',2) ; 
plot(1,NaN,lp{2},'Color',darkred,'LineWidth',2); hold on 
set(hSub, 'Visible', 'off');
h = legend(hSub,sprintf('M-Regime: Baseline'), ...
                sprintf('F-Regime: Baseline'), ...
                sprintf('M-Regime: Inflationary Shock 0.1'), ...
                sprintf('F-Regime: Inflationary Shock 0.1'), ...
                sprintf('M-Regime: Inflationary Shock 0.2'), ...
                sprintf('F-Regime: Inflationary Shock 0.2'),'Orientation','Horizontal','NumColumns',2);
h.FontSize = 8 ;
h.Interpreter = 'latex';
h.Location = 'northoutside' ;
h.ItemTokenSize = [15,18];

fig1.PaperUnits='inches';
fig1.PaperPosition=[0 0 8 7];

print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C2.png'))  ;
print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C2.eps'))  ;

%% Delte Dynare Subfiles
cd Dynare
delete MIU_Baseline_ZLB.log Baseline_ZLB_HistB.log Baseline_ZLB_PiShock.log ;
delete para_file.mat shock_file.mat shock_file_default.mat ss_initial.mat;
rmdir('+MIU_Baseline_ZLB','s'); rmdir('MIU_Baseline_ZLB','s');
rmdir('+Baseline_ZLB_HistB','s'); rmdir('Baseline_ZLB_HistB','s');
rmdir('+Baseline_ZLB_PiShock','s'); rmdir('Baseline_ZLB_PiShock','s');
cd ..
