clear; clc; close all;

Initialization ;

xi_shock_values = [-0.0664554546546023	-0.2158402772618420	-0.2116002099700470];
yH_shock_values = [-0.0427695295662761	-0.0087350940445975	0.0259595483391810];
lH_shock_values = [-0.0897949884559149	0.1657476479089390	0.1655317365515420];
noshocks        = [0 0 0] ;

save Dynare//shock_file_default lH_shock_values yH_shock_values xi_shock_values

%% ************************************************************************ 
%   Different ZLB Duration (Online_Appendix Table C.14)
%  ************************************************************************

for iii = 1:5
    if iii == 1;        rho_xi = 0 ;
    elseif iii == 2;    rho_xi = 0.2 ;
    elseif iii == 3;    rho_xi = 0.4 ;
    elseif iii == 4;    rho_xi = 0.6 ;
    elseif iii == 5;    rho_xi = 0.65 ;
    end
    save Dynare//para_file rho_xi -append ;

    %% Without transfers
    load('Dynare/shock_file_default')
    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

    %% Monetary regime
    FindSS ;
    psi_b   = 0.0/bss ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
           S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
           wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H] ;
    M_var = var ;

    var = round(var,7)  ;
    var_ss = var(1,:) ;

    for k = 1:30
        if k == 13
            var(:,13) = (var(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var(:,k) = (var(:,k)./var_ss(k)-1)*100 ;
        end
    end

    ZLB_dur(iii) = sum(var(1:15,13)==0) ;

    %% Fiscal Regime
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;


    %% With transfer
    load('Dynare/shock_file_default')
    transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values
    
    %% Monetary regime with transfer: three period
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;
    
    %% Fiscal regime with transfer: three period
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    %% Calculate Multipliers
    L = length(M_var_transfer_t3(2:end,1)) ;
    betas = (beta.^(0:1:L-1))' ;

        temp_y = betas.*(M_var_transfer_t3(2:end,7) - M_var(2:end,7)) ;
        temp_yr= betas.*(M_var_transfer_t3(2:end,8) - M_var(2:end,8)) ;
        temp_cr= betas.*(M_var_transfer_t3(2:end,1) - M_var(2:end,1)) ;
        temp_ch= betas.*(M_var_transfer_t3(2:end,2) - M_var(2:end,2)) ;
        temp_t = betas.*(M_var_transfer_t3(2:end,28) - M_var(2:end,28)) ;
        temp_y_ss = betas.*(M_var(2:end,7) - M_var_transfer_t3(1,7)) ;
        temp_yr_ss= betas.*(M_var(2:end,8) - M_var_transfer_t3(1,8)) ;
        temp_cr_ss= betas.*(M_var(2:end,1) - M_var_transfer_t3(1,1)) ;
        temp_ch_ss= betas.*(M_var(2:end,2) - M_var_transfer_t3(1,2)) ;
        temp_t_ss = betas.*(M_var(2:end,28) - M_var_transfer_t3(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var(2:end,7)) ;
        temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var(2:end,8)) ;
        temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var(2:end,1)) ;
        temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var(2:end,2)) ;
        temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var(2:end,28)) ;

    for i = 1:length(temp_y)
        M_PVm_y(i,1) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,1) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,1) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,1) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,1) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,1) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,1) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,1) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_ss(i,1) = sum(temp_y_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_ss(i,1) = sum(temp_yr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_ss(i,1) = sum(temp_cr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_ss(i,1) = sum(temp_ch_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase_ss(i,1) = sum(temp_y_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase_ss(i,1) = sum(temp_yr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase_ss(i,1) = sum(temp_cr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase_ss(i,1) = sum(temp_ch_ss(1:i))/sum(temp_t(1:i)) ;
    end

    M_y  = round([M_PVm_y([1 24],1)],3) ;
    M_yr = round([M_PVm_yr([1 24],1)],3) ;
    M_cr = round([M_PVm_cr([1 24],1)],3) ;
    M_ch = round([M_PVm_ch([1 24],1)],3) ;
    F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
    F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
    F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
    F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;
    if iii == 1
    Panel_A = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C14{iii} = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    elseif iii == 2
    Panel_B = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C14{iii} = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    elseif iii == 3
    Panel_C = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C14{iii} = table(Panel_C,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    elseif iii == 4
    Panel_D = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C14{iii} = table(Panel_D,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    elseif iii == 5
    Panel_E = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C14{iii} = table(Panel_E,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    end

end


%% ************************************************************************ 
%   Only preference shocks (Online_Appendix Tables C.15 and C.16)
%  ************************************************************************
for iii = 1:4
    load('Dynare/shock_file_default')
    yH_shock_values = noshocks; lH_shock_values = noshocks;
    if iii == 1
        rho_xi = 0 ;
    elseif iii == 2
        rho_xi = 0.8 ;
    elseif iii == 3
        rho_xi = 0.0 ;
        xi_shock_values = [-0.5 0 0];
    elseif iii == 4
        rho_xi = 0.8 ;
        xi_shock_values = [-0.5 0 0];
    end
    save Dynare//para_file rho_xi -append ;
    
    %% Without transfer
    transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

    %% Monetary Regime
    FindSS ;
    psi_b   = 0.0/bss ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
           S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
           wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H] ;
    M_var = var ;

    var = round(var,7)  ;
    var_ss = var(1,:) ;

    for k = 1:30
        if k == 13
            var(:,13) = (var(:,13) - 1)*100 ;
        elseif var_ss(k) ~= 0  
            var(:,k) = (var(:,k)./var_ss(k)-1)*100 ;
        end
    end
    
    welfare_AMPF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_R(1) = (util_R(1)) ;
    w_util_AMPF_H(1) = (util_H(1)) ;
    mu_AMPF_R(1) = 0 ;
    mu_AMPF_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_R(k) = util_R(k) ;
        w_util_AMPF_H(k) = util_H(k) ;
        else
        w_util_AMPF_R(k) = w_util_AMPF_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_H(k) = w_util_AMPF_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_H(k) - util_H(1)) -1)*100 ;
    end

    %% Fiscal Regime
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_PMAF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_R(1) = (util_R(1)) ;
    w_util_PMAF_H(1) = (util_H(1)) ;
    mu_PMAF_R(1) = 0 ;
    mu_PMAF_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_R(k) = util_R(k) ;
        w_util_PMAF_H(k) = util_H(k) ;
        else
        w_util_PMAF_R(k) = w_util_PMAF_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_H(k) = w_util_PMAF_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_H(k) - util_H(1)) -1)*100 ;
    end

    %% With transfer
    transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values
    
    %% Monetary Regime with transfer: three period
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_AMPF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_AMPF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_AMPF_t3_R(1) = (util_R(1)) ;
    w_util_AMPF_t3_H(1) = (util_H(1)) ;
    mu_AMPF_t3_R(1) = 0 ;
    mu_AMPF_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_AMPF_t3_R(k) = util_R(k) ;
        w_util_AMPF_t3_H(k) = util_H(k) ;
        else
        w_util_AMPF_t3_R(k) = w_util_AMPF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_AMPF_t3_H(k) = w_util_AMPF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_AMPF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_R(k) - util_R(1)) -1)*100 ;
        mu_AMPF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_H(k) - util_H(1)) -1)*100 ;
    end

    %% Fiscal Regime with transfer: three period
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;

    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

    M_var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    welfare_PMAF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
    welfare_PMAF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

    w_util_PMAF_t3_R(1) = (util_R(1)) ;
    w_util_PMAF_t3_H(1) = (util_H(1)) ;
    mu_PMAF_t3_R(1) = 0 ;
    mu_PMAF_t3_H(1) = 0 ;
    for k = 2:length(util_R)
        if k == 2
        w_util_PMAF_t3_R(k) = util_R(k) ;
        w_util_PMAF_t3_H(k) = util_H(k) ;
        else
        w_util_PMAF_t3_R(k) = w_util_PMAF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
        w_util_PMAF_t3_H(k) = w_util_PMAF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
        end
        mu_PMAF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_R(k) - util_R(1)) -1)*100 ;
        mu_PMAF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_H(k) - util_H(1)) -1)*100 ;
    end

    %% Calculate Multipliers
    L = length(M_var_transfer_t3(2:end,1)) ;
    betas = (beta.^(0:1:L-1))' ;

        temp_y = betas.*(M_var_transfer_t3(2:end,7) - M_var(2:end,7)) ;
        temp_yr= betas.*(M_var_transfer_t3(2:end,8) - M_var(2:end,8)) ;
        temp_cr= betas.*(M_var_transfer_t3(2:end,1) - M_var(2:end,1)) ;
        temp_ch= betas.*(M_var_transfer_t3(2:end,2) - M_var(2:end,2)) ;
        temp_t = betas.*(M_var_transfer_t3(2:end,28) - M_var(2:end,28)) ;
        temp_y_ss = betas.*(M_var(2:end,7) - M_var_transfer_t3(1,7)) ;
        temp_yr_ss= betas.*(M_var(2:end,8) - M_var_transfer_t3(1,8)) ;
        temp_cr_ss= betas.*(M_var(2:end,1) - M_var_transfer_t3(1,1)) ;
        temp_ch_ss= betas.*(M_var(2:end,2) - M_var_transfer_t3(1,2)) ;
        temp_t_ss = betas.*(M_var(2:end,28) - M_var_transfer_t3(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var(2:end,7)) ;
        temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var(2:end,8)) ;
        temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var(2:end,1)) ;
        temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var(2:end,2)) ;
        temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var(2:end,28)) ;

    for i = 1:length(temp_y)
        M_PVm_y(i,1) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,1) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,1) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,1) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,1) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,1) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,1) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,1) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_ss(i,1) = sum(temp_y_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_ss(i,1) = sum(temp_yr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_ss(i,1) = sum(temp_cr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_ss(i,1) = sum(temp_ch_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase_ss(i,1) = sum(temp_y_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase_ss(i,1) = sum(temp_yr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase_ss(i,1) = sum(temp_cr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase_ss(i,1) = sum(temp_ch_ss(1:i))/sum(temp_t(1:i)) ;
    end

    M_y  = round([M_PVm_y([1 24],1)],3) ;
    M_yr = round([M_PVm_yr([1 24],1)],3) ;
    M_cr = round([M_PVm_cr([1 24],1)],3) ;
    M_ch = round([M_PVm_ch([1 24],1)],3) ;
    F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
    F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
    F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
    F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;

    W_long_M    = round([welfare_AMPF_R_t3-welfare_AMPF_R ; welfare_AMPF_H_t3-welfare_AMPF_H],3) ;
    W_long_F    = round([welfare_PMAF_R_t3-welfare_AMPF_R ; welfare_PMAF_H_t3-welfare_AMPF_H],3) ;
    W_short_M   = round([mu_AMPF_t3_R(5)-mu_AMPF_R(5) ; mu_AMPF_t3_H(5)-mu_AMPF_H(5)],3) ;
    W_short_F   = round([mu_PMAF_t3_R(5)-mu_AMPF_R(5) ; mu_PMAF_t3_H(5)-mu_AMPF_H(5)],3) ;
    if iii == 1
    Panel_A = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C15{iii} = table(Panel_A,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    Panel_A = {'Ricardian','HtM'}' ;
    Online_Appendix_Table_C16{iii} = table(Panel_A,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif iii == 2
    Panel_B = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C15{iii} = table(Panel_B,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    Panel_B = {'Ricardian','HtM'}' ;
    Online_Appendix_Table_C16{iii} = table(Panel_B,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif iii == 3
    Panel_C = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C15{iii} = table(Panel_C,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    Panel_C = {'Ricardian','HtM'}' ;
    Online_Appendix_Table_C16{iii} = table(Panel_C,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif iii == 4
    Panel_D = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C15{iii} = table(Panel_D,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    Panel_D = {'Ricardian','HtM'}' ;
    Online_Appendix_Table_C16{iii} = table(Panel_D,W_long_M,W_short_M,W_long_F,W_short_F) ;
    elseif iii == 5
    Panel_E = {'Impact','4-Year'}' ;
    Online_Appendix_Table_C15{iii} = table(Panel_E,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;
    Panel_E = {'Ricardian','HtM'}' ;
    Online_Appendix_Table_C16{iii} = table(Panel_E,W_long_M,W_short_M,W_long_F,W_short_F) ;
    end


end


%%
clc ;
disp('    =================================================================================================')
disp('    ***      Online_Appendix Table C.14. Multipliers with Different Duration of Binding ZLB Periods      ***')
disp('    =================================================================================================')

fprintf('   Panel A: ZLB Duration=%d\n',ZLB_dur(1));
disp(Online_Appendix_Table_C14{1});

fprintf('   Panel B: ZLB Duration=%d\n',ZLB_dur(2));
disp(Online_Appendix_Table_C14{2});

fprintf('   Panel C: ZLB Duration=%d\n',ZLB_dur(3));
disp(Online_Appendix_Table_C14{3});

fprintf('   Panel D: ZLB Duration=%d\n',ZLB_dur(4));
disp(Online_Appendix_Table_C14{4});

fprintf('   Panel E: ZLB Duration=%d\n',ZLB_dur(5));
disp(Online_Appendix_Table_C14{5});
disp(' ')
writetable(Online_Appendix_Table_C14{1},'..\Output_Table\Online_Appendix_Table_C14.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C14{2},'..\Output_Table\Online_Appendix_Table_C14.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C14{3},'..\Output_Table\Online_Appendix_Table_C14.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C14{4},'..\Output_Table\Online_Appendix_Table_C14.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C14{5},'..\Output_Table\Online_Appendix_Table_C14.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 


disp('    ==============================================================================')
disp('    ***      Online_Appendix Table C.15. Multipliers with Only Preference Shocks      ***')
disp('    ==============================================================================')

fprintf('   Panel A: Calibrated baseline preference shocks: ρβ = 0.0)\n');
disp(Online_Appendix_Table_C15{1});

fprintf('   Panel B: Calibrated baseline preference shocks: ρβ = 0.8)\n');
disp(Online_Appendix_Table_C15{2});

fprintf('   Panel C: Shock to initial period: -50%%: ρβ = 0.0\n');
disp(Online_Appendix_Table_C15{3});

fprintf('   Panel D: Shock to initial period: -50%%: ρβ = 0.8\n');
disp(Online_Appendix_Table_C15{4});
disp(' ')
writetable(Online_Appendix_Table_C15{1},'..\Output_Table\Online_Appendix_Table_C15.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C15{2},'..\Output_Table\Online_Appendix_Table_C15.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C15{3},'..\Output_Table\Online_Appendix_Table_C15.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C15{4},'..\Output_Table\Online_Appendix_Table_C15.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 



disp('    ================================================================================')
disp('    ***      Online_Appendix Table C.16. Welfare Gains with Only Preference Shocks      ***')
disp('    ================================================================================')

fprintf('   Panel A: Calibrated baseline preference shocks: ρβ = 0.0)\n');
disp(Online_Appendix_Table_C16{1});

fprintf('   Panel B: Calibrated baseline preference shocks: ρβ = 0.8)\n');
disp(Online_Appendix_Table_C16{2});

fprintf('   Panel C: Shock to initial period: -50%%: ρβ = 0.0\n');
disp(Online_Appendix_Table_C16{3});

fprintf('   Panel D: Shock to initial period: -50%%: ρβ = 0.8\n');
disp(Online_Appendix_Table_C16{4});
writetable(Online_Appendix_Table_C16{1},'..\Output_Table\Online_Appendix_Table_C16.csv','WriteRowNames',true);
writetable(Online_Appendix_Table_C16{2},'..\Output_Table\Online_Appendix_Table_C16.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C16{3},'..\Output_Table\Online_Appendix_Table_C16.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 
writetable(Online_Appendix_Table_C16{4},'..\Output_Table\Online_Appendix_Table_C16.csv','WriteMode','Append',...
    'WriteVariableNames',true,'WriteRowNames',true) 

%% Delte Dynare Subfiles
cd Dynare
delete Baseline_ZLB.log ;
delete para_file.mat shock_file.mat shock_file_default.mat ss_initial.mat;
rmdir('+Baseline_ZLB','s'); rmdir('Baseline_ZLB','s');
cd ..
