clear; clc; close all;

Initialization ;

xi_shock_values = [-0.0664554546546023	-0.2158402772618420	-0.2116002099700470];
yH_shock_values = [-0.0427695295662761	-0.0087350940445975	0.0259595483391810];
lH_shock_values = [-0.0897949884559149	0.1657476479089390	0.1655317365515420];
noshocks        = [0 0 0] ;

save Dynare//shock_file_default lH_shock_values yH_shock_values xi_shock_values


%% ************************************************************************ 
%   Compare Models (Baseline vs. Without ZLB vs. Linear Model 
%   (Online_Appendix Figure C.1)
%  ************************************************************************
%% Baseline model: Monetary regime
FindSS ;
psi_b   = 0.0/bss ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
          (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
          (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
       S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
       wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H] ;

var = round(var,7)  ;
var_ss = var(1,:) ;

for k = 1:30
    if k == 13
        var(:,13) = (var(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var(:,k) = (var(:,k)./var_ss(k)-1)*100 ;
    end
end

%% Baseline model: Fiscal regime
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;

var_PMAF = round(var_PMAF,7)  ;
var_ss = var_PMAF(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF(:,13) = (var_PMAF(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF(:,k) = (var_PMAF(:,k)./var_ss(k)-1)*100 ;
    end
end

%% Baseline model: Monetary regime with transfer
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
          (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
          (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
   
var_transfer_t3 = round(var_transfer_t3,7)  ;
var_ss = var_transfer_t3(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3(:,13) = (var_transfer_t3(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3(:,k) = (var_transfer_t3(:,k)./var_ss(k)-1)*100 ;
    end
end

var_transfer_t3_baseline = var_transfer_t3 ;

%% Baseline model: Fiscal regime with transfer
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
   
var_PMAF_transfer_t3 = round(var_PMAF_transfer_t3,7)  ;
var_ss = var_PMAF_transfer_t3(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3(:,13) = (var_PMAF_transfer_t3(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3(:,k) = (var_PMAF_transfer_t3(:,k)./var_ss(k)-1)*100 ;
    end
end


%% ************************************************************************
%   Without ZLB
%  ************************************************************************

%% Without ZLB: Monetary regime
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_nozlb = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;

var_nozlb = round(var_nozlb,7)  ;
var_ss = var_nozlb(1,:) ;

for k = 1:30
    if k == 13
        var_nozlb(:,13) = (var_nozlb(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_nozlb(:,k) = (var_nozlb(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Without ZLB: Fiscal regime
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_nozlb = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;

var_PMAF_nozlb = round(var_PMAF_nozlb,7)  ;
var_ss = var_PMAF_nozlb(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_nozlb(:,13) = (var_PMAF_nozlb(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_nozlb(:,k) = (var_PMAF_nozlb(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Without ZLB: Monetary regime with transfer
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_t3_nozlb = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
   
var_transfer_t3_nozlb = round(var_transfer_t3_nozlb,7)  ;
var_ss = var_transfer_t3_nozlb(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3_nozlb(:,13) = (var_transfer_t3_nozlb(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3_nozlb(:,k) = (var_transfer_t3_nozlb(:,k)./var_ss(k)-1)*100 ;
    end
end

%% Without ZLB: Fiscal regime with transfer
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3_nozlb = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
   
var_PMAF_transfer_t3_nozlb = round(var_PMAF_transfer_t3_nozlb,7)  ;
var_ss = var_PMAF_transfer_t3_nozlb(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3_nozlb(:,13) = (var_PMAF_transfer_t3_nozlb(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3_nozlb(:,k) = (var_PMAF_transfer_t3_nozlb(:,k)./var_ss(k)-1)*100 ;
    end
end


%% ************************************************************************
%   Without ZLB: Linear model
%  ************************************************************************

%% Linear model: Monetary regime 
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB_Linear noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_nozlb_linear = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;

var_nozlb_linear = round(var_nozlb_linear,7)  ;
var_ss = var_nozlb_linear(1,:) ;

for k = 1:30
    if k == 13
        var_nozlb_linear(:,13) = (var_nozlb_linear(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_nozlb_linear(:,k) = (var_nozlb_linear(:,k)./var_ss(k)-1)*100 ;
    end
end

%% Linear model: Fiscal regime 
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB_Linear noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_nozlb_linear = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;

var_PMAF_nozlb_linear = round(var_PMAF_nozlb_linear,7)  ;
var_ss = var_PMAF_nozlb_linear(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_nozlb_linear(:,13) = (var_PMAF_nozlb_linear(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_nozlb_linear(:,k) = (var_PMAF_nozlb_linear(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Linear model: Monetary regime with transfer
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB_Linear noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_t3_nozlb_linear = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
   
var_transfer_t3_nozlb_linear = round(var_transfer_t3_nozlb_linear,7)  ;
var_ss = var_transfer_t3_nozlb_linear(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3_nozlb_linear(:,13) = (var_transfer_t3_nozlb_linear(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3_nozlb_linear(:,k) = (var_transfer_t3_nozlb_linear(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Linear model: Fiscal regime with transfer
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_withoutZLB_Linear noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3_nozlb_linear = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
   
var_PMAF_transfer_t3_nozlb_linear = round(var_PMAF_transfer_t3_nozlb_linear,7)  ;
var_ss = var_PMAF_transfer_t3_nozlb_linear(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3_nozlb_linear(:,13) = (var_PMAF_transfer_t3_nozlb_linear(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3_nozlb_linear(:,k) = (var_PMAF_transfer_t3_nozlb_linear(:,k)./var_ss(k)-1)*100 ;
    end
end


%% ************************************************************************
%   Multipliers State-dependence (Online_Appendix Figure C.3)
%  ************************************************************************
t_size = sort(unique([-1.5:0.1:-0.1 0.1:0.1:1.5])) ;
i_pos = find(t_size==1);
i_neg = find(t_size==-1);

for iii = 1:length(t_size)
    %% Monetary regime with transfer: No shocks
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.1/bss   ;   % labor tax rate rule
    phi_pi  = 1.58  ;
    phi_x   = 0.44/4;
    phi_dy  = 2.21  ;
    
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;
    
    xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
    transfer_values = t_size(iii)*[0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    
    save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values
    
    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;
    
    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    
    M_var_transfer_t3_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;
        
    %% Fisal regime with transfer: No shocks
    FindSS ;
    psi_b   = 0.0 ;   % Lump-sum tax rule
    psi_LR  = 0.00000001   ;   % labor tax rate rule
    phi_pi  = 0.00000001   ;
    phi_x   = 0.0   ;
    phi_dy  = 0.0   ;
    
    save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;
    
    xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
    transfer_values = t_size(iii)*[0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;
    
    save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values
    
    cd Dynare ;
        dynare Baseline_ZLB noclearall
    cd .. ;
    
    pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;
    
    M_var_PMAF_transfer_t3_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
           R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
           th tauL_R tauL_H transfer transfer_R transfer_H] ;

    %% Calculate Multipliers
    L = length(M_var_transfer_t3_noshock(2:end,1)) ;
    betas = (beta.^(0:1:L-1))' ;
    
    temp_y_noshock_ss = betas.*(M_var_transfer_t3_noshock(2:end,7) - M_var_transfer_t3_noshock(1,7)) ;
    temp_yr_noshock_ss= betas.*(M_var_transfer_t3_noshock(2:end,8) - M_var_transfer_t3_noshock(1,8)) ;
    temp_cr_noshock_ss= betas.*(M_var_transfer_t3_noshock(2:end,1) - M_var_transfer_t3_noshock(1,1)) ;
    temp_ch_noshock_ss= betas.*(M_var_transfer_t3_noshock(2:end,2) - M_var_transfer_t3_noshock(1,2)) ;
    temp_t_noshock_ss = betas.*(M_var_transfer_t3_noshock(2:end,28) - M_var_transfer_t3_noshock(1,28)) ;
    temp_y_PMAF_mbase_noshock_ss = betas.*(M_var_PMAF_transfer_t3_noshock(2:end,7) - M_var_PMAF_transfer_t3_noshock(1,7)) ;
    temp_yr_PMAF_mbase_noshock_ss= betas.*(M_var_PMAF_transfer_t3_noshock(2:end,8) - M_var_PMAF_transfer_t3_noshock(1,8)) ;
    temp_cr_PMAF_mbase_noshock_ss= betas.*(M_var_PMAF_transfer_t3_noshock(2:end,1) - M_var_PMAF_transfer_t3_noshock(1,1)) ;
    temp_ch_PMAF_mbase_noshock_ss= betas.*(M_var_PMAF_transfer_t3_noshock(2:end,2) - M_var_PMAF_transfer_t3_noshock(1,2)) ;
    temp_t_PMAF_mbase_noshock_ss = betas.*(M_var_PMAF_transfer_t3_noshock(2:end,28) - M_var_PMAF_transfer_t3_noshock(1,28)) ;
            
    for i = 1:length(temp_y_noshock_ss)
        denom = abs(sum(temp_t_noshock_ss(1:i))) ;
        M_PVm_y_noshock_ss(i,1) = sum(temp_y_noshock_ss(1:i))/denom ;
        M_PVm_yr_noshock_ss(i,1) = sum(temp_yr_noshock_ss(1:i))/denom ;
        M_PVm_cr_noshock_ss(i,1) = sum(temp_cr_noshock_ss(1:i))/denom ;
        M_PVm_ch_noshock_ss(i,1) = sum(temp_ch_noshock_ss(1:i))/denom ;
        M_PVm_y_PMAF_mbase_noshock_ss(i,1) = sum(temp_y_PMAF_mbase_noshock_ss(1:i))/denom ;
        M_PVm_yr_PMAF_mbase_noshock_ss(i,1) = sum(temp_yr_PMAF_mbase_noshock_ss(1:i))/denom ;
        M_PVm_cr_PMAF_mbase_noshock_ss(i,1) = sum(temp_cr_PMAF_mbase_noshock_ss(1:i))/denom ;
        M_PVm_ch_PMAF_mbase_noshock_ss(i,1) = sum(temp_ch_PMAF_mbase_noshock_ss(1:i))/denom ;
    end

    M_y(:,iii)  = round([M_PVm_y_noshock_ss([1 24],1)],3) ;
    M_yr(:,iii) = round([M_PVm_yr_noshock_ss([1 24],1)],3) ;
    M_cr(:,iii) = round([M_PVm_cr_noshock_ss([1 24],1)],3) ;
    M_ch(:,iii) = round([M_PVm_ch_noshock_ss([1 24],1)],3) ;
    F_y(:,iii)  = round([M_PVm_y_PMAF_mbase_noshock_ss([1 24],1)],3) ;
    F_yr(:,iii) = round([M_PVm_yr_PMAF_mbase_noshock_ss([1 24],1)],3) ;
    F_cr(:,iii) = round([M_PVm_cr_PMAF_mbase_noshock_ss([1 24],1)],3) ;
    F_ch(:,iii) = round([M_PVm_ch_PMAF_mbase_noshock_ss([1 24],1)],3) ;
end

M_table{1} = M_y ;  var_fig_names{1} = '$\mathcal{M}(Y)$';
M_table{2} = M_yr;  var_fig_names{2} = '$\mathcal{M}(Y_R)$';
M_table{3} = M_cr;  var_fig_names{3} = '$\mathcal{M}(C^R)$';
M_table{4} = M_ch;  var_fig_names{4} = '$\mathcal{M}(C^H)$';
M_table{5} = F_y ;  var_fig_names{5} = '$\mathcal{M}(Y)$';
M_table{6} = F_yr;  var_fig_names{6} = '$\mathcal{M}(Y_R)$';
M_table{7} = F_cr;  var_fig_names{7} = '$\mathcal{M}(C^R)$';
M_table{8} = F_ch;  var_fig_names{8} = '$\mathcal{M}(C^H)$';


%% Online_Appendix Figure C.1
figure_index_pi = [14 17 18 14 17 18];
fig1 = figure;
for i = 1:6
    j = figure_index_pi(i) ;
    subplot(3,3,i)
    if i<=3
    plot(0:Short_Horizon,var(1:Short_Horizon+1,j),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_nozlb(1:Short_Horizon+1,j),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_nozlb_linear(1:Short_Horizon+1,j),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    ylabel('Monetary Regime','Interpreter','Latex','FontSize',9) ;
    else
    plot(0:Short_Horizon,var_PMAF(1:Short_Horizon+1,j),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_nozlb(1:Short_Horizon+1,j),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_nozlb_linear(1:Short_Horizon+1,j),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    ylabel('Fiscal Regime','Interpreter','Latex','FontSize',9) ;
    end
    axis tight

    set(gca,'Xcolor',[0 0 0],'XTick',0:2:Short_Horizon,'FontSize',8,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'off'  ;

    title(var_fig_names{j},'Interpreter','Latex','FontSize',12) ;
    %ylabel('percent','Interpreter','Latex','FontSize',8) ;

    if i>=7
        xlabel('Time','Interpreter','Latex','FontSize',8) ;
    end
end
hSub = subplot(3,3,7:9) ;
plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; 
plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2) ; 
plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2) ; 
set(hSub, 'Visible', 'off');
h = legend(hSub,sprintf('Baseline'), ...
                sprintf('Without ZLB'), ...
                sprintf('Without ZLB, Linear Appx'),'Orientation','Horizontal');
h.FontSize = 10 ;
h.Interpreter = 'latex';
h.Location = 'northoutside' ;
h.ItemTokenSize = [15,18];

fig1.PaperUnits='inches';
fig1.PaperPosition=[0 0 6.5 4];
print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C1A.png'))  ;
print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C1A.eps'))  ;


fig1 = figure;
for i = 1:6
    j = figure_index_pi(i) ;
    subplot(3,3,i)
    if i<=3
    plot(0:Short_Horizon,var_transfer_t3(1:Short_Horizon+1,j),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_transfer_t3_nozlb(1:Short_Horizon+1,j),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_transfer_t3_nozlb_linear(1:Short_Horizon+1,j),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    ylabel('Monetary Regime','Interpreter','Latex','FontSize',9) ;
    else
    plot(0:Short_Horizon,var_PMAF_transfer_t3(1:Short_Horizon+1,j),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_transfer_t3_nozlb(1:Short_Horizon+1,j),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_transfer_t3_nozlb_linear(1:Short_Horizon+1,j),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    ylabel('Fiscal Regime','Interpreter','Latex','FontSize',9) ;
    end
    axis tight

    set(gca,'Xcolor',[0 0 0],'XTick',0:2:Short_Horizon,'FontSize',8,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'off'  ;

    title(var_fig_names{j},'Interpreter','Latex','FontSize',12) ;
    %ylabel('percent','Interpreter','Latex','FontSize',8) ;

    if i>=7
        xlabel('Time','Interpreter','Latex','FontSize',8) ;
    end
end
hSub = subplot(3,3,7:9) ;
plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; 
plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2) ; 
plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2) ; 
set(hSub, 'Visible', 'off');
h = legend(hSub,sprintf('Baseline'), ...
                sprintf('Without ZLB'), ...
                sprintf('Without ZLB, Linear Appx'),'Orientation','Horizontal');
h.FontSize = 10 ;
h.Interpreter = 'latex';
h.Location = 'northoutside' ;
h.ItemTokenSize = [15,18];

fig1.PaperUnits='inches';
fig1.PaperPosition=[0 0 6.5 4];
print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C1B.png'))  ;
print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C1B.eps'))  ;


%% Online_Appendix Figure C.3
fig1 = figure;
for i = 1:4
    subplot(3,4,i)
    plot(t_size(t_size>=0)*0.268,M_table{i}(1,t_size>=0),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(t_size(t_size>=0)*0.268,M_table{i+4}(1,t_size>=0),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(-1*t_size(t_size<=0)*0.268,M_table{i}(1,t_size<=0),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    plot(-1*t_size(t_size<=0)*0.268,M_table{i+4}(1,t_size<=0),lp{4},'Color',tab_orange,'linewidth',2) ; hold on
    a_max = min(100,max(max([M_table{i}(1,t_size>0) M_table{i+4}(1,t_size>0) ]))); 
    a_min = min(min([M_table{i}(1,t_size>0) M_table{i+4}(1,t_size>0)]));
    aaa   = max([a_max abs(a_min)]) ;
    gap = (a_max-a_min)/10;
    plot([t_size(i_pos) t_size(i_pos)]*0.268,[-aaa-gap aaa+gap],'-.k','linewidth',1)
    axis tight

    set(gca,'Xcolor',[0 0 0],'XTick',[0:0.1:0.4],'YLim',[-aaa-gap aaa+gap],'FontSize',6.0,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on' ,'gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;
    hh = gca ; hh.YBaseline.Visible = 'on'  ;
    title(var_fig_names{i},'Interpreter','Latex','FontSize',10) ;
    if i == 1
        ylabel('Impact Multipliers','Interpreter','Latex','FontSize',8) ;
    end

    subplot(3,4,i+4)
    plot(t_size(t_size>=0)*0.268,M_table{i}(2,t_size>=0),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(t_size(t_size>=0)*0.268,M_table{i+4}(2,t_size>=0),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(-1*t_size(t_size<=0)*0.268,M_table{i}(2,t_size<=0),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    plot(-1*t_size(t_size<=0)*0.268,M_table{i+4}(2,t_size<=0),lp{4},'Color',tab_orange,'linewidth',2) ; hold on
    a_max = min(100,max(max([M_table{i}(2,t_size>0) M_table{i+4}(2,t_size>0) ]))); 
    a_min = min(min([M_table{i}(2,t_size>0) M_table{i+4}(2,t_size>0)]));
    aaa   = max([a_max abs(a_min)]) ;
    gap = (a_max-a_min)/10;
    plot([t_size(i_pos) t_size(i_pos)]*0.268,[-aaa-gap aaa+gap],'-.k','linewidth',1)
    axis tight

    set(gca,'Xcolor',[0 0 0],'XTick',[0:0.1:0.4],'YLim',[-aaa-gap aaa+gap],'FontSize',6.0,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on' ,'gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;
    hh = gca ; hh.YBaseline.Visible = 'on'  ;
    title(var_fig_names{i},'Interpreter','Latex','FontSize',10) ;
    if i == 1
        ylabel('4-Year Multipliers','Interpreter','Latex','FontSize',8) ;
    end
    xlabel('Size of Transfer Shocks','Interpreter','Latex','FontSize',7.5) ;
end
hSub = subplot(3,4,[9 12]) ;
plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; 
plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2) ; 
plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2); hold on ; 
plot(1,NaN,lp{4},'Color',tab_orange,'LineWidth',2) ; 
set(hSub, 'Visible', 'off');
h = legend(hSub,['M-Regime: Transfer Increase'], ...
                ['F-Regime: Transfer Increase'], ...
                ['M-Regime: Transfer Decrease'], ...
                ['F-Regime: Transfer Decrease'], ...
                'Orientation','Horizontal','NumColumns',2);
h.FontSize = 7 ;
h.Interpreter = 'latex';
h.Location = 'northoutside' ;
h.ItemTokenSize = [15,18];

fig1.PaperUnits='inches';
fig1.PaperPosition=[0 0 8 5];
print('-depsc',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C3.eps'))  ;
print('-dpng',sprintf('..\\Output_Figure\\Online_Appendix_Figure_C3.png'))  ;

%% Delte Dynare Subfiles
cd Dynare
delete Baseline_ZLB.log Baseline_withoutZLB.log Baseline_withoutZLB_Linear.log ;
delete para_file.mat shock_file.mat shock_file_default.mat ss_initial.mat;
rmdir('+Baseline_ZLB','s'); rmdir('Baseline_ZLB','s');
rmdir('+Baseline_withoutZLB','s'); rmdir('Baseline_withoutZLB','s');
rmdir('+Baseline_withoutZLB_Linear','s'); rmdir('Baseline_withoutZLB_Linear','s');
cd ..

