clear; clc; close all;

%% ************************************************************************ 
%   Baseline
%  ************************************************************************
Initialization ;

xi_shock_values = [-0.0664554546546023	-0.2158402772618420	-0.2116002099700470];
yH_shock_values = [-0.0427695295662761	-0.0087350940445975	0.0259595483391810];
lH_shock_values = [-0.0897949884559149	0.1657476479089390	0.1655317365515420];
noshocks        = [0 0 0] ;

save Dynare//shock_file_default lH_shock_values yH_shock_values xi_shock_values

%% Monetary Regime
FindSS ;
psi_b   = 0.0/bss ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
          (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
          (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

var = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q ...
       S_R S_H R pi pi_cpiR pi_cpiH pi_R pi_H lR lH ...
       wR wH b lumpsum_tax th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var = var ;

var = round(var,7)  ;
var_ss = var(1,:) ;

for k = 1:30
    if k == 13
        var(:,13) = (var(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var(:,k) = (var(:,k)./var_ss(k)-1)*100 ;
    end
end

welfare_AMPF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
welfare_AMPF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

w_util_AMPF_R(1) = (util_R(1)) ;
w_util_AMPF_H(1) = (util_H(1)) ;
mu_AMPF_R(1) = 0 ;
mu_AMPF_H(1) = 0 ;
for k = 2:length(util_R)
    if k == 2
    w_util_AMPF_R(k) = util_R(k) ;
    w_util_AMPF_H(k) = util_H(k) ;
    else
    w_util_AMPF_R(k) = w_util_AMPF_R(k-1) + beta^(k-2)*util_R(k) ;
    w_util_AMPF_H(k) = w_util_AMPF_H(k-1) + beta^(k-2)*util_H(k) ;
    end
    mu_AMPF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_R(k) - util_R(1)) -1)*100 ;
    mu_AMPF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_H(k) - util_H(1)) -1)*100 ;
end


gdp1q = (c(1)+c(2)/2) ; 
gdp2q = (c(3)+c(2)/2) ;
gdp3q = (c(4)+c(5)/2) ;


L_H     = round(target(1:3)',2) ;
L_R     = round(target(4:6)',2) ;
Pi_H    = round(target(7:9)',2) ;
Pi_R    = round([(pi_R(2)-1) (pi_R(2)*pi_R(3)-1) (pi_R(2)*pi_R(3)*pi_R(4)-1)]'*100,2) ;
C_H     = round(var(2:4,2),2) ;
C_R     = round(var(2:4,1),2) ;
C       = round(var(2:4,7),2) ;
GDP     = round([(gdp2q/gdp1q-1)*100;(gdp3q/gdp1q-1)*100;0],3) ;
var_title = {'April','June','August'}' ;
Table_Calibration_WithoutT = table(var_title,L_H,L_R,Pi_H,Pi_R,C_H,C_R,C,GDP) ;

agg_pi = alpha_R*pi_R + (1-alpha_R)*pi_H ;

%% Fiscal Regime
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0 0 0 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF = var_PMAF ;

var_PMAF = round(var_PMAF,7)  ;
var_ss = var_PMAF(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF(:,13) = (var_PMAF(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF(:,k) = (var_PMAF(:,k)./var_ss(k)-1)*100 ;
    end
end

welfare_PMAF_R = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
welfare_PMAF_H = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

w_util_PMAF_R(1) = (util_R(1)) ;
w_util_PMAF_H(1) = (util_H(1)) ;
mu_PMAF_R(1) = 0 ;
mu_PMAF_H(1) = 0 ;
for k = 2:length(util_R)
    if k == 2
    w_util_PMAF_R(k) = util_R(k) ;
    w_util_PMAF_H(k) = util_H(k) ;
    else
    w_util_PMAF_R(k) = w_util_PMAF_R(k-1) + beta^(k-2)*util_R(k) ;
    w_util_PMAF_H(k) = w_util_PMAF_H(k-1) + beta^(k-2)*util_H(k) ;
    end
    mu_PMAF_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_R(k) - util_R(1)) -1)*100 ;
    mu_PMAF_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_H(k) - util_H(1)) -1)*100 ;
end

agg_pi_PMAF = alpha_R*pi_R + (1-alpha_R)*pi_H ;

%% Monetary Regime with transfer: three period
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

target = [(lH(2)/lH(1)-1) (lH(3)/lH(1)-1) (lH(4)/lH(1)-1) ...
          (lR(2)/lR(1)-1) (lR(3)/lR(1)-1) (lR(4)/lR(1)-1) ...
          (pi_H(2)-1) (pi_H(2)*pi_H(3)-1) (pi_H(2)*pi_H(3)*pi_H(4)-1)]*100 ;

var_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_transfer_t3 = var_transfer_t3;
   
var_transfer_t3 = round(var_transfer_t3,7)  ;
var_ss = var_transfer_t3(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3(:,13) = (var_transfer_t3(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3(:,k) = (var_transfer_t3(:,k)./var_ss(k)-1)*100 ;
    end
end

welfare_AMPF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
welfare_AMPF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

w_util_AMPF_t3_R(1) = (util_R(1)) ;
w_util_AMPF_t3_H(1) = (util_H(1)) ;
mu_AMPF_t3_R(1) = 0 ;
mu_AMPF_t3_H(1) = 0 ;
for k = 2:length(util_R)
    if k == 2
    w_util_AMPF_t3_R(k) = util_R(k) ;
    w_util_AMPF_t3_H(k) = util_H(k) ;
    else
    w_util_AMPF_t3_R(k) = w_util_AMPF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
    w_util_AMPF_t3_H(k) = w_util_AMPF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
    end
    mu_AMPF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_R(k) - util_R(1)) -1)*100 ;
    mu_AMPF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_AMPF_t3_H(k) - util_H(1)) -1)*100 ;
end


var_transfer_t3_baseline = var_transfer_t3 ;

gdp1q = (c(1)+c(2)/2) ; 
gdp2q = (c(3)+c(2)/2) ;
gdp3q = (c(4)+c(5)/2) ;

L_H     = round(target(1:3)',2) ;
L_R     = round(target(4:6)',2) ;
Pi_H    = round(target(7:9)',2) ;
Pi_R    = round([(pi_R(2)-1) (pi_R(2)*pi_R(3)-1) (pi_R(2)*pi_R(3)*pi_R(4)-1)]'*100,2) ;
C_H     = round(var_transfer_t3_baseline(2:4,2),2) ;
C_R     = round(var_transfer_t3_baseline(2:4,1),2) ;
C       = round(var_transfer_t3_baseline(2:4,7),2) ;
GDP     = round([(gdp2q/gdp1q-1)*100;(gdp3q/gdp1q-1)*100;0],2) ;
Online_Appendix_Table_C1 = {'April','June','August'}' ;
Table_Calibration_withT = table(Online_Appendix_Table_C1,L_H,L_R,Pi_H,Pi_R,C_H,C_R,C,GDP) ;

agg_pi_transfer_t3 = alpha_R*pi_R + (1-alpha_R)*pi_H ;

%% Fiscal Regime with transfer: three period
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

load('Dynare/shock_file_default')
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3 = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF_transfer_t3 = var_PMAF_transfer_t3;
   
var_PMAF_transfer_t3 = round(var_PMAF_transfer_t3,7)  ;
var_ss = var_PMAF_transfer_t3(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3(:,13) = (var_PMAF_transfer_t3(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3(:,k) = (var_PMAF_transfer_t3(:,k)./var_ss(k)-1)*100 ;
    end
end

welfare_PMAF_R_t3 = (exp((1-beta)*V_R(2) - util_R(1)) - 1)*100 ;
welfare_PMAF_H_t3 = (exp((1-beta)*V_H(2) - util_H(1)) - 1)*100 ;

w_util_PMAF_t3_R(1) = (util_R(1)) ;
w_util_PMAF_t3_H(1) = (util_H(1)) ;
mu_PMAF_t3_R(1) = 0 ;
mu_PMAF_t3_H(1) = 0 ;
for k = 2:length(util_R)
    if k == 2
    w_util_PMAF_t3_R(k) = util_R(k) ;
    w_util_PMAF_t3_H(k) = util_H(k) ;
    else
    w_util_PMAF_t3_R(k) = w_util_PMAF_t3_R(k-1) + beta^(k-2)*util_R(k) ;
    w_util_PMAF_t3_H(k) = w_util_PMAF_t3_H(k-1) + beta^(k-2)*util_H(k) ;
    end
    mu_PMAF_t3_R(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_R(k) - util_R(1)) -1)*100 ;
    mu_PMAF_t3_H(k) = ( exp((1-beta)/(1-beta^(k-1))*w_util_PMAF_t3_H(k) - util_H(1)) -1)*100 ;
end

agg_pi_PMAF_transfer_t3 = alpha_R*pi_R + (1-alpha_R)*pi_H ;

%% Monetary Regime with transfer (no Covid shocks): three period
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_t3_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_transfer_t3_noshock = var_transfer_t3_noshock;
   
var_transfer_t3_noshock = round(var_transfer_t3_noshock,7)  ;
var_ss = var_transfer_t3_noshock(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3_noshock(:,13) = (var_transfer_t3_noshock(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3_noshock(:,k) = (var_transfer_t3_noshock(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Fiscal Regime with transfer (no Covid shocks): three period
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF_transfer_t3_noshock = var_PMAF_transfer_t3_noshock;
   
var_PMAF_transfer_t3_noshock = round(var_PMAF_transfer_t3_noshock,7)  ;
var_ss = var_PMAF_transfer_t3_noshock(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3_noshock(:,13) = (var_PMAF_transfer_t3_noshock(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3_noshock(:,k) = (var_PMAF_transfer_t3_noshock(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Monetary Regime with transfer (no Covid shock, flex price): three period
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare FlexiblePrice noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_flx_t3_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_transfer_flx_t3_noshock = var_transfer_flx_t3_noshock;
   
var_transfer_flx_t3_noshock = round(var_transfer_flx_t3_noshock,7)  ;
var_ss = var_transfer_flx_t3_noshock(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_flx_t3_noshock(:,13) = (var_transfer_flx_t3_noshock(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_flx_t3_noshock(:,k) = (var_transfer_flx_t3_noshock(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Fiscal Regime with transfer (no Covid shock, flex price): three period
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare FlexiblePrice noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_flx_t3_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF_transfer_flx_t3_noshock = var_PMAF_transfer_flx_t3_noshock;
   
var_PMAF_transfer_flx_t3_noshock = round(var_PMAF_transfer_flx_t3_noshock,7)  ;
var_ss = var_PMAF_transfer_flx_t3_noshock(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_flx_t3_noshock(:,13) = (var_PMAF_transfer_flx_t3_noshock(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_flx_t3_noshock(:,k) = (var_PMAF_transfer_flx_t3_noshock(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Monetary Regime with transfer (no Covid shock, flex price): three period: lump-sum tax
FindSS ;
psi_b   = 0.6 ;   % Lump-sum tax rule
psi_LR  = 0.0/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare FlexiblePrice noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_flx_t3_lumpsum_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_transfer_flx_t3_lumpsum_noshock = var_transfer_flx_t3_lumpsum_noshock;
   
var_transfer_flx_t3_lumpsum_noshock = round(var_transfer_flx_t3_lumpsum_noshock,7)  ;
var_ss = var_transfer_flx_t3_lumpsum_noshock(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_flx_t3_lumpsum_noshock(:,13) = (var_transfer_flx_t3_lumpsum_noshock(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_flx_t3_lumpsum_noshock(:,k) = (var_transfer_flx_t3_lumpsum_noshock(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Fiscal Regime with transfer (no Covid shock, flex price): three period: lump-sum tax
FindSS ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare FlexiblePrice noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_flx_t3_lumpsum_noshock = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF_transfer_flx_t3_lumpsum_noshock = var_PMAF_transfer_flx_t3_lumpsum_noshock;
   
var_PMAF_transfer_flx_t3_lumpsum_noshock = round(var_PMAF_transfer_flx_t3_lumpsum_noshock,7)  ;
var_ss = var_PMAF_transfer_flx_t3_lumpsum_noshock(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_flx_t3_lumpsum_noshock(:,13) = (var_PMAF_transfer_flx_t3_lumpsum_noshock(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_flx_t3_lumpsum_noshock(:,k) = (var_PMAF_transfer_flx_t3_lumpsum_noshock(:,k)./var_ss(k)-1)*100 ;
    end
end


%% Representative Agent model
Initialization ;
lambda = 0 ;
alpha_R = 1;
alpha_H = 0;
xi = 0 ;
save Dynare//para_file lambda alpha_R alpha_H xi -append ;


%% RA: AMPF with transfer (no Covid shocks): three period
FindSS_RA ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.1/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB_RA noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_t3_noshock_RA = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_transfer_t3_noshock_RA = var_transfer_t3_noshock_RA;

var_transfer_t3_noshock_RA = round(var_transfer_t3_noshock_RA,7)  ;
var_ss = var_transfer_t3_noshock_RA(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3_noshock_RA(:,13) = (var_transfer_t3_noshock_RA(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3_noshock_RA(:,k) = (var_transfer_t3_noshock_RA(:,k)./var_ss(k)-1)*100 ;
    end
end

%% RA: PMAF with transfer (no Covid shocks): three period
FindSS_RA ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB_RA noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3_noshock_RA = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF_transfer_t3_noshock_RA = var_PMAF_transfer_t3_noshock_RA;

var_PMAF_transfer_t3_noshock_RA = round(var_PMAF_transfer_t3_noshock_RA,7)  ;
var_ss = var_PMAF_transfer_t3_noshock_RA(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3_noshock_RA(:,13) = (var_PMAF_transfer_t3_noshock_RA(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3_noshock_RA(:,k) = (var_PMAF_transfer_t3_noshock_RA(:,k)./var_ss(k)-1)*100 ;
    end
end

%% RA: AMPF with transfer (no Covid shocks): three period: lump-sum
FindSS_RA ;
psi_b   = 0.1 ;   % Lump-sum tax rule
psi_LR  = 0.0/bss   ;   % labor tax rate rule
phi_pi  = 1.58  ;
phi_x   = 0.44/4;
phi_dy  = 2.21  ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB_RA noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_transfer_t3_lumpsum_noshock_RA = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_transfer_t3_lumpsum_noshock_RA = var_transfer_t3_lumpsum_noshock_RA;

var_transfer_t3_lumpsum_noshock_RA = round(var_transfer_t3_lumpsum_noshock_RA,7)  ;
var_ss = var_transfer_t3_lumpsum_noshock_RA(1,:) ;

for k = 1:30
    if k == 13
        var_transfer_t3_lumpsum_noshock_RA(:,13) = (var_transfer_t3_lumpsum_noshock_RA(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_transfer_t3_lumpsum_noshock_RA(:,k) = (var_transfer_t3_lumpsum_noshock_RA(:,k)./var_ss(k)-1)*100 ;
    end
end


%% RA: PMAF with transfer (no Covid shocks): three period: lump-sum
FindSS_RA ;
psi_b   = 0.0 ;   % Lump-sum tax rule
psi_LR  = 0.00000001/bss   ;   % labor tax rate rule
phi_pi  = 0.00000001   ;
phi_x   = 0.0   ;
phi_dy  = 0.0   ;

save Dynare//para_file psi_b psi_LR phi_pi phi_x phi_dy -append ;

xi_shock_values = noshocks;  yH_shock_values = noshocks;  lH_shock_values = noshocks;
transfer_values = [0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0.268/(1+beta+beta^2) 0 0 0 0 0 0 0 0 0] ;

save Dynare//shock_file lH_shock_values yH_shock_values xi_shock_values transfer_values

cd Dynare ;
    dynare Baseline_ZLB_RA noclearall
cd .. ;

pi  = (1-lambda)*pi_cpiR + lambda*pi_cpiH   ;

var_PMAF_transfer_t3_lumpsum_noshock_RA = [cR cH cR_R cR_H cH_R cH_H c y_R y_H Q S_R S_H ...
       R pi pi_cpiR pi_cpiH pi_R pi_H lR lH wR wH b lumpsum_tax ...
       th tauL_R tauL_H transfer transfer_R transfer_H] ;
M_var_PMAF_transfer_t3_lumpsum_noshock_RA = var_PMAF_transfer_t3_lumpsum_noshock_RA;

var_PMAF_transfer_t3_lumpsum_noshock_RA = round(var_PMAF_transfer_t3_lumpsum_noshock_RA,7)  ;
var_ss = var_PMAF_transfer_t3_lumpsum_noshock_RA(1,:) ;

for k = 1:30
    if k == 13
        var_PMAF_transfer_t3_lumpsum_noshock_RA(:,13) = (var_PMAF_transfer_t3_lumpsum_noshock_RA(:,13) - 1)*100 ;
    elseif var_ss(k) ~= 0  
        var_PMAF_transfer_t3_lumpsum_noshock_RA(:,k) = (var_PMAF_transfer_t3_lumpsum_noshock_RA(:,k)./var_ss(k)-1)*100 ;
    end
end

%% Calculate Multipliers
Initialization ;
L = length(M_var_transfer_t3(2:end,1)) ;
betas = (beta.^(0:1:L-1))' ;

for j = 1:3
    if j == 1   % Distribution Horizon = 3
        temp_y = betas.*(M_var_transfer_t3(2:end,7) - M_var(2:end,7)) ;
        temp_yr= betas.*(M_var_transfer_t3(2:end,8) - M_var(2:end,8)) ;
        temp_cr= betas.*(M_var_transfer_t3(2:end,1) - M_var(2:end,1)) ;
        temp_ch= betas.*(M_var_transfer_t3(2:end,2) - M_var(2:end,2)) ;
        temp_t = betas.*(M_var_transfer_t3(2:end,28) - M_var(2:end,28)) ;
        temp_y_noshock = betas.*(M_var_transfer_t3(2:end,7) - M_var_transfer_t3_noshock(2:end,7)) ;
        temp_yr_noshock= betas.*(M_var_transfer_t3(2:end,8) - M_var_transfer_t3_noshock(2:end,8)) ;
        temp_cr_noshock= betas.*(M_var_transfer_t3(2:end,1) - M_var_transfer_t3_noshock(2:end,1)) ;
        temp_ch_noshock= betas.*(M_var_transfer_t3(2:end,2) - M_var_transfer_t3_noshock(2:end,2)) ;
        temp_t_noshock = betas.*(M_var_transfer_t3(2:end,28) - M_var_transfer_t3_noshock(2:end,28)) ;
        temp_y_noshock_ss = betas.*(M_var_transfer_t3_noshock(2:end,7) - M_var_transfer_t3(1,7)) ;
        temp_yr_noshock_ss= betas.*(M_var_transfer_t3_noshock(2:end,8) - M_var_transfer_t3(1,8)) ;
        temp_cr_noshock_ss= betas.*(M_var_transfer_t3_noshock(2:end,1) - M_var_transfer_t3(1,1)) ;
        temp_ch_noshock_ss= betas.*(M_var_transfer_t3_noshock(2:end,2) - M_var_transfer_t3(1,2)) ;
        temp_t_noshock_ss = betas.*(M_var_transfer_t3_noshock(2:end,28) - M_var_transfer_t3(1,28)) ;
        temp_y_ss = betas.*(M_var(2:end,7) - M_var_transfer_t3(1,7)) ;
        temp_yr_ss= betas.*(M_var(2:end,8) - M_var_transfer_t3(1,8)) ;
        temp_cr_ss= betas.*(M_var(2:end,1) - M_var_transfer_t3(1,1)) ;
        temp_ch_ss= betas.*(M_var(2:end,2) - M_var_transfer_t3(1,2)) ;
        temp_t_ss = betas.*(M_var(2:end,28) - M_var_transfer_t3(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var(2:end,7)) ;
        temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var(2:end,8)) ;
        temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var(2:end,1)) ;
        temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var(2:end,2)) ;
        temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var(2:end,28)) ;
        temp_y_PMAF_mbase_noshock = betas.*(M_var_PMAF_transfer_t3(2:end,7) - M_var_PMAF_transfer_t3_noshock(2:end,7)) ;
        temp_yr_PMAF_mbase_noshock= betas.*(M_var_PMAF_transfer_t3(2:end,8) - M_var_PMAF_transfer_t3_noshock(2:end,8)) ;
        temp_cr_PMAF_mbase_noshock= betas.*(M_var_PMAF_transfer_t3(2:end,1) - M_var_PMAF_transfer_t3_noshock(2:end,1)) ;
        temp_ch_PMAF_mbase_noshock= betas.*(M_var_PMAF_transfer_t3(2:end,2) - M_var_PMAF_transfer_t3_noshock(2:end,2)) ;
        temp_t_PMAF_mbase_noshock = betas.*(M_var_PMAF_transfer_t3(2:end,28) - M_var_PMAF_transfer_t3_noshock(2:end,28)) ;
        temp_y_PMAF_mbase_noshock_ss = betas.*(M_var_PMAF_transfer_t3_noshock(2:end,7) - M_var_transfer_t3(1,7)) ;
        temp_yr_PMAF_mbase_noshock_ss= betas.*(M_var_PMAF_transfer_t3_noshock(2:end,8) - M_var_transfer_t3(1,8)) ;
        temp_cr_PMAF_mbase_noshock_ss= betas.*(M_var_PMAF_transfer_t3_noshock(2:end,1) - M_var_transfer_t3(1,1)) ;
        temp_ch_PMAF_mbase_noshock_ss= betas.*(M_var_PMAF_transfer_t3_noshock(2:end,2) - M_var_transfer_t3(1,2)) ;
        temp_t_PMAF_mbase_noshock_ss = betas.*(M_var_PMAF_transfer_t3_noshock(2:end,28) - M_var_transfer_t3(1,28)) ;
    elseif j == 2   % Distribution Horizon = 3, Flexible prices, without shocks
        temp_y = betas.*(M_var_transfer_flx_t3_noshock(2:end,7) - M_var_transfer_flx_t3_noshock(1,7)) ;
        temp_yr= betas.*(M_var_transfer_flx_t3_noshock(2:end,8) - M_var_transfer_flx_t3_noshock(1,8)) ;
        temp_cr= betas.*(M_var_transfer_flx_t3_noshock(2:end,1) - M_var_transfer_flx_t3_noshock(1,1)) ;
        temp_ch= betas.*(M_var_transfer_flx_t3_noshock(2:end,2) - M_var_transfer_flx_t3_noshock(1,2)) ;
        temp_t = betas.*(M_var_transfer_flx_t3_noshock(2:end,28) - M_var_transfer_flx_t3_noshock(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_noshock(2:end,7) - M_var_transfer_flx_t3_noshock(1,7)) ;
        temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_noshock(2:end,8) - M_var_transfer_flx_t3_noshock(1,8)) ;
        temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_noshock(2:end,1) - M_var_transfer_flx_t3_noshock(1,1)) ;
        temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_noshock(2:end,2) - M_var_transfer_flx_t3_noshock(1,2)) ;
        temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_noshock(2:end,28) - M_var_transfer_flx_t3_noshock(1,28)) ;
    elseif j == 3   % Distribution Horizon = 3, Flexible prices, without shocks, lump-sum tax adjust
        temp_y = betas.*(M_var_transfer_flx_t3_lumpsum_noshock(2:end,7) - M_var_transfer_flx_t3_noshock(1,7)) ;
        temp_yr= betas.*(M_var_transfer_flx_t3_lumpsum_noshock(2:end,8) - M_var_transfer_flx_t3_noshock(1,8)) ;
        temp_cr= betas.*(M_var_transfer_flx_t3_lumpsum_noshock(2:end,1) - M_var_transfer_flx_t3_noshock(1,1)) ;
        temp_ch= betas.*(M_var_transfer_flx_t3_lumpsum_noshock(2:end,2) - M_var_transfer_flx_t3_noshock(1,2)) ;
        temp_t = betas.*(M_var_transfer_flx_t3_lumpsum_noshock(2:end,28) - M_var_transfer_flx_t3_noshock(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_lumpsum_noshock(2:end,7) - M_var_transfer_flx_t3_noshock(1,7)) ;
        temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_lumpsum_noshock(2:end,8) - M_var_transfer_flx_t3_noshock(1,8)) ;
        temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_lumpsum_noshock(2:end,1) - M_var_transfer_flx_t3_noshock(1,1)) ;
        temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_lumpsum_noshock(2:end,2) - M_var_transfer_flx_t3_noshock(1,2)) ;
        temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_flx_t3_lumpsum_noshock(2:end,28) - M_var_transfer_flx_t3_noshock(1,28)) ;
    end
        
    for i = 1:length(temp_y)
        M_PVm_y(i,j) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,j) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,j) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,j) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,j) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,j) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,j) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,j) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        if j == 1
        M_PVm_y_noshock(i,j) = sum(temp_y_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_noshock(i,j) = sum(temp_yr_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_noshock(i,j) = sum(temp_cr_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_noshock(i,j) = sum(temp_ch_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase_noshock(i,j) = sum(temp_y_PMAF_mbase_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase_noshock(i,j) = sum(temp_yr_PMAF_mbase_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase_noshock(i,j) = sum(temp_cr_PMAF_mbase_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase_noshock(i,j) = sum(temp_ch_PMAF_mbase_noshock(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_noshock_ss(i,j) = sum(temp_y_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_noshock_ss(i,j) = sum(temp_yr_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_noshock_ss(i,j) = sum(temp_cr_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_noshock_ss(i,j) = sum(temp_ch_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase_noshock_ss(i,j) = sum(temp_y_PMAF_mbase_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase_noshock_ss(i,j) = sum(temp_yr_PMAF_mbase_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase_noshock_ss(i,j) = sum(temp_cr_PMAF_mbase_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase_noshock_ss(i,j) = sum(temp_ch_PMAF_mbase_noshock_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_ss(i,j) = sum(temp_y_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_ss(i,j) = sum(temp_yr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_ss(i,j) = sum(temp_cr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_ss(i,j) = sum(temp_ch_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase_ss(i,j) = sum(temp_y_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase_ss(i,j) = sum(temp_yr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase_ss(i,j) = sum(temp_cr_ss(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase_ss(i,j) = sum(temp_ch_ss(1:i))/sum(temp_t(1:i)) ;
        end
    end
end

% Table 2: Multipliers
M_y  = round([M_PVm_y([1 24],1)],3) ;
M_yr = round([M_PVm_yr([1 24],1)],3) ;
M_cr = round([M_PVm_cr([1 24],1)],3) ;
M_ch = round([M_PVm_ch([1 24],1)],3) ;
F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)],3) ;
F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1)],3) ;
F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1)],3) ;
F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1)],3) ;
Table2 = {'Impact','4-Year'}' ;
Table_Baseline = table(Table2,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;

% Table 3: Welfares
W_long_M    = round([welfare_AMPF_R_t3-welfare_AMPF_R ; welfare_AMPF_H_t3-welfare_AMPF_H],3) ;
W_long_F    = round([welfare_PMAF_R_t3-welfare_AMPF_R ; welfare_PMAF_H_t3-welfare_AMPF_H],3) ;
W_short_M   = round([mu_AMPF_t3_R(5)-mu_AMPF_R(5) ; mu_AMPF_t3_H(5)-mu_AMPF_H(5)],3) ;
W_short_F   = round([mu_PMAF_t3_R(5)-mu_AMPF_R(5) ; mu_PMAF_t3_H(5)-mu_AMPF_H(5)],3) ;

Table3 = {'Ricardian','HtM'}' ;
Table_Welfare = table(Table3,W_long_M,W_short_M,W_long_F,W_short_F) ;

mu_AMPF_agg     = (1-lambda)*mu_AMPF_R + lambda*mu_AMPF_H ;
mu_AMPF_t3_agg  = (1-lambda)*mu_AMPF_t3_R + lambda*mu_AMPF_t3_H ;
mu_PMAF_t3_agg  = (1-lambda)*mu_PMAF_t3_R + lambda*mu_PMAF_t3_H ;

fig_short_AMPF_agg  = mu_AMPF_t3_agg-mu_AMPF_agg ;
fig_short_AMPF_R    = mu_AMPF_t3_R-mu_AMPF_R ;
fig_short_AMPF_H    = mu_AMPF_t3_H-mu_AMPF_H ;
fig_short_PMAF_agg  = mu_PMAF_t3_agg-mu_AMPF_agg ;
fig_short_PMAF_R    = mu_PMAF_t3_R-mu_AMPF_R ;
fig_short_PMAF_H    = mu_PMAF_t3_H-mu_AMPF_H ;

% Table 4: Decomposition
M_y  = round([M_PVm_y([1 24],1)  ; M_PVm_y_noshock([1 24],1)  ; M_PVm_y_noshock_ss([1 24],1)  ; M_PVm_y_ss([1 24],1)],3)    ;
M_yr = round([M_PVm_yr([1 24],1) ; M_PVm_yr_noshock([1 24],1) ; M_PVm_yr_noshock_ss([1 24],1) ; M_PVm_yr_ss([1 24],1)],3)   ;
M_cr = round([M_PVm_cr([1 24],1) ; M_PVm_cr_noshock([1 24],1) ; M_PVm_cr_noshock_ss([1 24],1) ; M_PVm_cr_ss([1 24],1)],3)   ;
M_ch = round([M_PVm_ch([1 24],1) ; M_PVm_ch_noshock([1 24],1) ; M_PVm_ch_noshock_ss([1 24],1) ; M_PVm_ch_ss([1 24],1)],3)   ;
F_y  = round([M_PVm_y_PMAF_mbase([1 24],1)  ; M_PVm_y_PMAF_mbase_noshock([1 24],1)  ; M_PVm_y_PMAF_mbase_noshock_ss([1 24],1)  ; M_PVm_y_PMAF_mbase_ss([1 24],1)],3)  ;
F_yr = round([M_PVm_yr_PMAF_mbase([1 24],1) ; M_PVm_yr_PMAF_mbase_noshock([1 24],1) ; M_PVm_yr_PMAF_mbase_noshock_ss([1 24],1) ; M_PVm_yr_PMAF_mbase_ss([1 24],1)],3) ;
F_cr = round([M_PVm_cr_PMAF_mbase([1 24],1) ; M_PVm_cr_PMAF_mbase_noshock([1 24],1) ; M_PVm_cr_PMAF_mbase_noshock_ss([1 24],1) ; M_PVm_cr_PMAF_mbase_ss([1 24],1)],3) ;
F_ch = round([M_PVm_ch_PMAF_mbase([1 24],1) ; M_PVm_ch_PMAF_mbase_noshock([1 24],1) ; M_PVm_ch_PMAF_mbase_noshock_ss([1 24],1) ; M_PVm_ch_PMAF_mbase_ss([1 24],1)],3) ;
M_y = M_y([1 3 5 7 2 4 6 8])     ; M_yr = M_yr([1 3 5 7 2 4 6 8])   ;
M_cr = M_cr([1 3 5 7 2 4 6 8])   ; M_ch = M_ch([1 3 5 7 2 4 6 8])   ;
F_y = F_y([1 3 5 7 2 4 6 8])     ; F_yr = F_yr([1 3 5 7 2 4 6 8])   ;
F_cr = F_cr([1 3 5 7 2 4 6 8])   ; F_ch = F_ch([1 3 5 7 2 4 6 8])   ;
Table4 = {'Impact: Total Effect','Impact: Covid Effect with Transfer','Impact: Transfer Effect without Covid','Impact: Covid Effect without Transfer', ...
             '4-Year: Total Effect','4-Year: Covid Effect with Transfer','4-Year: Transfer Effect without Covid','4-Year: Covid Effect without Transfer'}' ;
Table_Decomposition = table(Table4,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;

% Table 5: Without COVID Shocks
M_y  = round([M_PVm_y_noshock_ss([1 24],1)  ; M_PVm_y([1 24],2)  ; M_PVm_y([1 24],3)],3) ;
M_yr = round([M_PVm_yr_noshock_ss([1 24],1) ; M_PVm_yr([1 24],2) ; M_PVm_yr([1 24],3)],3) ;
M_cr = round([M_PVm_cr_noshock_ss([1 24],1) ; M_PVm_cr([1 24],2) ; M_PVm_cr([1 24],3)],3) ;
M_ch = round([M_PVm_ch_noshock_ss([1 24],1) ; M_PVm_ch([1 24],2) ; M_PVm_ch([1 24],3)],3) ;
F_y  = round([M_PVm_y_PMAF_mbase_noshock_ss([1 24],1)  ; M_PVm_y_PMAF_mbase([1 24],2)  ; M_PVm_y_PMAF_mbase([1 24],3)],3) ;
F_yr = round([M_PVm_yr_PMAF_mbase_noshock_ss([1 24],1) ; M_PVm_yr_PMAF_mbase([1 24],2) ; M_PVm_yr_PMAF_mbase([1 24],3)],3) ;
F_cr = round([M_PVm_cr_PMAF_mbase_noshock_ss([1 24],1) ; M_PVm_cr_PMAF_mbase([1 24],2) ; M_PVm_cr_PMAF_mbase([1 24],3)],3) ;
F_ch = round([M_PVm_ch_PMAF_mbase_noshock_ss([1 24],1) ; M_PVm_ch_PMAF_mbase([1 24],2) ; M_PVm_ch_PMAF_mbase([1 24],3)],3) ;
Table5 = {'No Covid & Sticky: Impact','No Covid & Sticky: 4-Year', ...
             'No Covid & Flexible: Impact','No Covid & Flexible: 4-Year', ...
             'No Covid & Flexible & Lump-sum: Impact','No Covid & Flexible & Lump-sum: 4-Year'}' ;
Table_NoCovidShock = table(Table5,M_y,M_yr,M_cr,M_ch,F_y,F_yr,F_cr,F_ch) ;

%% Calculate Multipliers for RA models
L = length(M_var_transfer_t3_noshock(2:end,1)) ;
betas = (beta.^(0:1:L-1))' ;

for j = 1:2
    if j == 1   % Distribution Horizon = 3
        temp_y = betas.*(M_var_transfer_t3_noshock_RA(2:end,7) - M_var_transfer_t3_noshock_RA(1,7)) ;
        temp_yr= betas.*(M_var_transfer_t3_noshock_RA(2:end,8) - M_var_transfer_t3_noshock_RA(1,8)) ;
        temp_cr= betas.*(M_var_transfer_t3_noshock_RA(2:end,1) - M_var_transfer_t3_noshock_RA(1,1)) ;
        temp_ch= betas.*(M_var_transfer_t3_noshock_RA(2:end,2) - M_var_transfer_t3_noshock_RA(1,2)) ;
        temp_t = betas.*(M_var_transfer_t3_noshock_RA(2:end,28)- M_var_transfer_t3_noshock_RA(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3_noshock_RA(2:end,7) - M_var_transfer_t3_noshock_RA(1,7)) ;
        temp_yr_PMAF_mbase= betas.*(M_var_PMAF_transfer_t3_noshock_RA(2:end,8) - M_var_transfer_t3_noshock_RA(1,8)) ;
        temp_cr_PMAF_mbase= betas.*(M_var_PMAF_transfer_t3_noshock_RA(2:end,1) - M_var_transfer_t3_noshock_RA(1,1)) ;
        temp_ch_PMAF_mbase= betas.*(M_var_PMAF_transfer_t3_noshock_RA(2:end,2) - M_var_transfer_t3_noshock_RA(1,2)) ;
        temp_t_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3_noshock_RA(2:end,28)- M_var_transfer_t3_noshock_RA(1,28)) ;
    elseif j == 2   % Distribution Horizon = 3, lump-sum tax
        temp_y = betas.*(M_var_transfer_t3_lumpsum_noshock_RA(2:end,7) - M_var_transfer_t3_lumpsum_noshock_RA(1,7)) ;
        temp_yr= betas.*(M_var_transfer_t3_lumpsum_noshock_RA(2:end,8) - M_var_transfer_t3_lumpsum_noshock_RA(1,8)) ;
        temp_cr= betas.*(M_var_transfer_t3_lumpsum_noshock_RA(2:end,1) - M_var_transfer_t3_lumpsum_noshock_RA(1,1)) ;
        temp_ch= betas.*(M_var_transfer_t3_lumpsum_noshock_RA(2:end,2) - M_var_transfer_t3_lumpsum_noshock_RA(1,2)) ;
        temp_t = betas.*(M_var_transfer_t3_lumpsum_noshock_RA(2:end,28) - M_var_transfer_t3_lumpsum_noshock_RA(1,28)) ;
        temp_y_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3_lumpsum_noshock_RA(2:end,7) - M_var_transfer_t3_lumpsum_noshock_RA(1,7)) ;
        temp_yr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3_lumpsum_noshock_RA(2:end,8) - M_var_transfer_t3_lumpsum_noshock_RA(1,8)) ;
        temp_cr_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3_lumpsum_noshock_RA(2:end,1) - M_var_transfer_t3_lumpsum_noshock_RA(1,1)) ;
        temp_ch_PMAF_mbase = betas.*(M_var_PMAF_transfer_t3_lumpsum_noshock_RA(2:end,2) - M_var_transfer_t3_lumpsum_noshock_RA(1,2)) ;
    end
    
    for i = 1:length(temp_y)
        M_PVm_y(i,j) = sum(temp_y(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr(i,j) = sum(temp_yr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr(i,j) = sum(temp_cr(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch(i,j) = sum(temp_ch(1:i))/sum(temp_t(1:i)) ;
        M_PVm_y_PMAF_mbase(i,j) = sum(temp_y_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_yr_PMAF_mbase(i,j) = sum(temp_yr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_cr_PMAF_mbase(i,j) = sum(temp_cr_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
        M_PVm_ch_PMAF_mbase(i,j) = sum(temp_ch_PMAF_mbase(1:i))/sum(temp_t(1:i)) ;
    end
end

% Multipliers
M_noCOVID = [M_PVm_y_noshock_ss([1 24],1); M_PVm_cr_noshock_ss([1 24],1)] ;
F_noCOVID = [M_PVm_y_PMAF_mbase_noshock_ss([1 24],1); M_PVm_cr_PMAF_mbase_noshock_ss([1 24],1)] ;

RA_M = [M_PVm_y([1 24],1); M_PVm_cr([1 24],1)] ;
RA_F = [M_PVm_y_PMAF_mbase([1 24],1); M_PVm_cr_PMAF_mbase([1 24],1)] ;

RA_LumpSum_M = [M_PVm_y([1 24],2); M_PVm_cr([1 24],2)] ;
RA_LumpSum_F = [M_PVm_y_PMAF_mbase([1 24],2); M_PVm_cr_PMAF_mbase([1 24],2)] ;

% Inflation volatility
var_noshock{1} = var_transfer_t3_noshock ;
var_PMAF_noshock{1} = var_PMAF_transfer_t3_noshock ;
var_noshock{2} = var_transfer_t3_noshock_RA ;
var_PMAF_noshock{2} = var_PMAF_transfer_t3_noshock_RA ;
var_noshock{3} = var_transfer_t3_lumpsum_noshock_RA ;
var_PMAF_noshock{3} = var_PMAF_transfer_t3_lumpsum_noshock_RA ;

for ii = 1:3
    pi_vol(ii) = sum((var_noshock{ii}(:,14)).^2) ;
    pi_vol_PMAF(ii) = sum((var_PMAF_noshock{ii}(:,14)).^2) ;
end

Y_M = round([M_noCOVID([1 2]) ; RA_M([1 2]) ; RA_LumpSum_M([1 2]) ],3);
CR_M= round([M_noCOVID([3 4]) ; RA_M([3 4]) ; RA_LumpSum_M([3 4]) ],3);
Pi_M= round([pi_vol(1)/pi_vol(1); NaN ; pi_vol(2)/pi_vol(1) ; NaN ; pi_vol(3)/pi_vol(1) ; NaN ],3);
Y_F = round([F_noCOVID([1 2]) ; RA_F([1 2]) ; RA_LumpSum_F([1 2]) ],3);
CR_F= round([F_noCOVID([3 4]) ; RA_F([3 4]) ; RA_LumpSum_F([3 4]) ],3);
Pi_F= round([pi_vol_PMAF(1)/pi_vol(1); NaN ; pi_vol_PMAF(2)/pi_vol(1); NaN ; pi_vol_PMAF(3)/pi_vol(1); NaN],3);

Table6 = {'Baseline: Impact','Baseline: 4-Year','RA Model: Impact','RA Model: 4-Year','RA Model Lump-Sum: Impact','RA Model Lump-Sum: 4-Year'}' ;
Table_RA = table(Table6,Y_M,CR_M,Pi_M,Y_F,CR_F,Pi_F) ;



%%
clc ;
disp('    ======================================')
disp('    ***      Table 2. Multipliers      ***')
disp('    ======================================')
disp(Table_Baseline);
disp(' ')
writetable(Table_Baseline,'..\Output_Table\Table2.csv','WriteRowNames',true);

disp('    ========================================')
disp('    ***      Table 3. Welfare Gains      ***')
disp('    ========================================')
disp(Table_Welfare);
disp(' ')
writetable(Table_Welfare,'..\Output_Table\Table3.csv','WriteRowNames',true);


disp('    ========================================')
disp('    ***      Table 4. Decomposition      ***')
disp('    ========================================')
disp(Table_Decomposition);
disp(' ')
writetable(Table_Decomposition,'..\Output_Table\Table4.csv','WriteRowNames',true);


disp('    ===========================================================')
disp('    ***      Table 5. Multipliers without COVID Shocks      ***')
disp('    ===========================================================')
disp(Table_NoCovidShock);
disp(' ')
writetable(Table_NoCovidShock,'..\Output_Table\Table5.csv','WriteRowNames',true);


disp('    ==============================================================================')
disp('    ***      Table 6. Multipliers and Var(Inflation) without COVID Shocks      ***')
disp('    ==============================================================================')
disp(Table_RA);
disp(' ')
writetable(Table_RA,'..\Output_Table\Table6.csv','WriteRowNames',true);


disp('    ===================================================')
disp('    ***      Online_Appendix Table C.1. Model Moments      ***')
disp('    ===================================================')
disp(Table_Calibration_withT);
writetable(Table_Calibration_withT,'..\Output_Table\Online_Appendix_Table_C1_Model.csv','WriteRowNames',true);



%% ================================
%  ***    Figure 1: Baseline    ***
%  ================================
figure_index = [1 2 7 8 17 18 13 23 26] ;

fig1 = figure;
for i = 1:9
    j = figure_index(i) ;
    subplot(4,3,i)
    plot(0:Short_Horizon,var(1:Short_Horizon+1,j),lp{1},'Color',tab_blue,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF(1:Short_Horizon+1,j),lp{2},'Color',tab_red,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_transfer_t3(1:Short_Horizon+1,j),lp{3},'Color',tab_green,'linewidth',2) ; hold on
    plot(0:Short_Horizon,var_PMAF_transfer_t3(1:Short_Horizon+1,j),lp{4},'Color',tab_orange,'linewidth',2) ; hold on
    axis tight

    set(gca,'Xcolor',[0 0 0],'XTick',0:2:Short_Horizon,'FontSize',7,'FontName','Times New Roman',...
        'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
    hh = gca ;
    hh.YBaseline.Visible = 'off'  ;

    title(var_fig_names{j},'Interpreter','Latex','FontSize',10) ;
    ylabel('percent','Interpreter','Latex','FontSize',8) ;

    if i>=7
        xlabel('Time','Interpreter','Latex','FontSize',8) ;
    end
end
hSub = subplot(4,3,10:12) ;
plot(1,NaN,lp{1},'Color',tab_blue,'LineWidth',2); hold on ; 
plot(1,NaN,lp{2},'Color',tab_red,'LineWidth',2) ; 
plot(1,NaN,lp{3},'Color',tab_green,'LineWidth',2) ; 
plot(1,NaN,lp{4},'Color',tab_orange,'LineWidth',2); hold on 
set(hSub, 'Visible', 'off');
h = legend(hSub,sprintf('M-Regime without Transfer'), ...
                sprintf('F-Regime without Transfer'), ...
                sprintf('M-Regime with Transfer'), ...
                sprintf('F-Regime with Transfer'),'Orientation','Horizontal');
h.FontSize = 8 ;
h.Interpreter = 'latex';
h.Location = 'northoutside' ;
h.ItemTokenSize = [15,18];

fig1.PaperUnits='inches';
fig1.PaperPosition=[0 0 8 7];
print('-depsc',sprintf('..\\Output_Figure\\Figure1.eps'))  ;
print('-dpng',sprintf('..\\Output_Figure\\Figure1.png'))  ;


%% ===============================================
%  ***    Figure 2: Short-run Welfare Gains    ***
%  ===============================================
l_length = 90 ;

fig1 = figure;
subplot(1,3,1)
plot([1:l_length]/6,fig_short_AMPF_agg(1:l_length),'-','Color',tab_blue,'linewidth',2) ; hold on;
plot([1:l_length]/6,fig_short_PMAF_agg(1:l_length),'-.','Color',tab_red,'linewidth',2) ; hold on;
set(gca,'Xcolor',[0 0 0],'XTick',[0:18:l_length]/6,'FontSize',8,'FontName','Times New Roman',...
    'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
hh = gca ; hh.YBaseline.Visible = 'on'  ;


title('Aggregate Welfare','Interpreter','Latex','FontSize',12) ;
ylabel('Percentage point','Interpreter','Latex','FontSize',9) ;
xlabel('Years','Interpreter','Latex','FontSize',9) ;

subplot(1,3,2)
plot([1:l_length]/6,fig_short_AMPF_R(1:l_length),'-','Color',tab_blue,'linewidth',2) ; hold on;
plot([1:l_length]/6,fig_short_PMAF_R(1:l_length),'-.','Color',tab_red,'linewidth',2) ; hold on;
a_min = min([fig_short_AMPF_R(1:l_length) fig_short_PMAF_R(1:l_length)]) ;
a_max = max([fig_short_AMPF_R(1:l_length) fig_short_PMAF_R(1:l_length)]) ;
a_step = (a_max-a_min)/10 ;
% plot([sum(fig_short_PMAF_R<0)+1 sum(fig_short_PMAF_R<0)+1]/6,[a_min-a_step a_max+a_step],'-k','linewidth',1)
set(gca,'Xcolor',[0 0 0],'FontSize',8,'XTick',[0:18:l_length]/6,'YLim',[a_min-a_step a_max+a_step],'FontName','Times New Roman',...
    'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
hh = gca ; hh.YBaseline.Visible = 'on'  ;

title('Ricardian Household','Interpreter','Latex','FontSize',12) ;
ylabel('Percentage point','Interpreter','Latex','FontSize',9) ;
xlabel('Years','Interpreter','Latex','FontSize',9) ;

subplot(1,3,3)
plot([1:l_length]/6,fig_short_AMPF_H(1:l_length),'-','Color',tab_blue,'linewidth',2) ; hold on;
plot([1:l_length]/6,fig_short_PMAF_H(1:l_length),'-.','Color',tab_red,'linewidth',2) ; hold on;
set(gca,'Xcolor',[0 0 0],'XTick',[0:18:l_length]/6,'FontSize',8,'FontName','Times New Roman',...
    'xgrid','on','ygrid','on','gridlinestyle',':','GridAlpha',0.3,'gridcolor','k') ;% 'TickLength',[ 0 0 ],
hh = gca ; hh.YBaseline.Visible = 'on'  ;

title('HTM Household','Interpreter','Latex','FontSize',12) ;
ylabel('Percentage point','Interpreter','Latex','FontSize',9) ;
xlabel('Years','Interpreter','Latex','FontSize',9) ;
h = legend('Monetary Regime','Fiscal Regime','Orientation','Vertical');
h.FontSize = 10 ;
h.Interpreter = 'latex';
h.ItemTokenSize = [12,18];

fig1.PaperUnits='inches';
fig1.PaperPosition=[0 0 8 3.0];

print('-depsc',sprintf('..\\Output_Figure\\Figure2.eps'))  ;
print('-dpng',sprintf('..\\Output_Figure\\Figure2.png'))  ;

%% Delte Dynare Subfiles
cd Dynare
delete Baseline_ZLB.log Baseline_ZLB_RA.log FlexiblePrice.log;
delete para_file.mat shock_file.mat shock_file_default.mat ss_initial.mat;
rmdir('+Baseline_ZLB','s'); rmdir('Baseline_ZLB','s');
rmdir('+Baseline_ZLB_RA','s'); rmdir('Baseline_ZLB_RA','s');
rmdir('+FlexiblePrice','s'); rmdir('FlexiblePrice','s');
cd ..
